@@ -20,8 +20,7 @@
 find . -type f \( \
   -name '*~' -o -name 'core' -o -name '*.core' \
   -o -name '*.log' -o -name '*.pid' -o -name '*.keyset' \
-  -o -name named.run -o -name ans.run \
-  -o -name '*-valgrind-*.log' \) -print | xargs rm -f
+  -o -name named.run -o -name ans.run \) -print | xargs rm -f
 
 status=0
 
