@@ -89,7 +89,7 @@ typedef struct sampledb sampledb_t;
 static isc_result_t
 sample_name_fromnode(dns_dbnode_t *node, dns_name_t *name) {
 	dns_rbtnode_t *rbtnode = (dns_rbtnode_t *)node;
-	return (dns_rbt_fullnamefromnode(rbtnode, name));
+	return dns_rbt_fullnamefromnode(rbtnode, name);
 }
 
 static void
@@ -136,7 +136,7 @@ beginload(dns_db_t *db, dns_rdatacallbacks_t *callbacks) {
 	FATAL_ERROR("current implementation should never call beginload()");
 
 	/* Not reached */
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 /*
@@ -152,7 +152,7 @@ endload(dns_db_t *db, dns_rdatacallbacks_t *callbacks) {
 	FATAL_ERROR("current implementation should never call endload()");
 
 	/* Not reached */
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -166,7 +166,7 @@ dump(dns_db_t *db, dns_dbversion_t *version, const char *filename,
 	FATAL_ERROR("current implementation should never call dump()");
 
 	/* Not reached */
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static void
@@ -184,7 +184,7 @@ newversion(dns_db_t *db, dns_dbversion_t **versionp) {
 
 	REQUIRE(VALID_SAMPLEDB(sampledb));
 
-	return (dns_db_newversion(sampledb->rbtdb, versionp));
+	return dns_db_newversion(sampledb->rbtdb, versionp);
 }
 
 static void
@@ -213,7 +213,7 @@ findnode(dns_db_t *db, const dns_name_t *name, bool create,
 
 	REQUIRE(VALID_SAMPLEDB(sampledb));
 
-	return (dns_db_findnode(sampledb->rbtdb, name, create, nodep));
+	return dns_db_findnode(sampledb->rbtdb, name, create, nodep);
 }
 
 static isc_result_t
@@ -225,8 +225,8 @@ find(dns_db_t *db, const dns_name_t *name, dns_dbversion_t *version,
 
 	REQUIRE(VALID_SAMPLEDB(sampledb));
 
-	return (dns_db_find(sampledb->rbtdb, name, version, type, options, now,
-			    nodep, foundname, rdataset, sigrdataset));
+	return dns_db_find(sampledb->rbtdb, name, version, type, options, now,
+			   nodep, foundname, rdataset, sigrdataset);
 }
 
 static isc_result_t
@@ -238,8 +238,8 @@ findzonecut(dns_db_t *db, const dns_name_t *name, unsigned int options,
 
 	REQUIRE(VALID_SAMPLEDB(sampledb));
 
-	return (dns_db_findzonecut(sampledb->rbtdb, name, options, now, nodep,
-				   foundname, dcname, rdataset, sigrdataset));
+	return dns_db_findzonecut(sampledb->rbtdb, name, options, now, nodep,
+				  foundname, dcname, rdataset, sigrdataset);
 }
 
 static void
@@ -266,7 +266,7 @@ expirenode(dns_db_t *db, dns_dbnode_t *node, isc_stdtime_t now) {
 
 	REQUIRE(VALID_SAMPLEDB(sampledb));
 
-	return (dns_db_expirenode(sampledb->rbtdb, node, now));
+	return dns_db_expirenode(sampledb->rbtdb, node, now);
 }
 
 static void
@@ -285,7 +285,7 @@ createiterator(dns_db_t *db, unsigned int options,
 
 	REQUIRE(VALID_SAMPLEDB(sampledb));
 
-	return (dns_db_createiterator(sampledb->rbtdb, options, iteratorp));
+	return dns_db_createiterator(sampledb->rbtdb, options, iteratorp);
 }
 
 static isc_result_t
@@ -296,8 +296,8 @@ findrdataset(dns_db_t *db, dns_dbnode_t *node, dns_dbversion_t *version,
 
 	REQUIRE(VALID_SAMPLEDB(sampledb));
 
-	return (dns_db_findrdataset(sampledb->rbtdb, node, version, type,
-				    covers, now, rdataset, sigrdataset));
+	return dns_db_findrdataset(sampledb->rbtdb, node, version, type, covers,
+				   now, rdataset, sigrdataset);
 }
 
 static isc_result_t
@@ -308,8 +308,8 @@ allrdatasets(dns_db_t *db, dns_dbnode_t *node, dns_dbversion_t *version,
 
 	REQUIRE(VALID_SAMPLEDB(sampledb));
 
-	return (dns_db_allrdatasets(sampledb->rbtdb, node, version, options,
-				    now, iteratorp));
+	return dns_db_allrdatasets(sampledb->rbtdb, node, version, options, now,
+				   iteratorp);
 }
 
 static isc_result_t
@@ -334,7 +334,7 @@ addrdataset(dns_db_t *db, dns_dbnode_t *node, dns_dbversion_t *version,
 	}
 
 cleanup:
-	return (result);
+	return result;
 }
 
 static isc_result_t
@@ -363,7 +363,7 @@ subtractrdataset(dns_db_t *db, dns_dbnode_t *node, dns_dbversion_t *version,
 	}
 
 cleanup:
-	return (result);
+	return result;
 }
 
 /*
@@ -377,8 +377,8 @@ deleterdataset(dns_db_t *db, dns_dbnode_t *node, dns_dbversion_t *version,
 
 	REQUIRE(VALID_SAMPLEDB(sampledb));
 
-	return (dns_db_deleterdataset(sampledb->rbtdb, node, version, type,
-				      covers));
+	return dns_db_deleterdataset(sampledb->rbtdb, node, version, type,
+				     covers);
 }
 
 static bool
@@ -387,7 +387,7 @@ issecure(dns_db_t *db) {
 
 	REQUIRE(VALID_SAMPLEDB(sampledb));
 
-	return (dns_db_issecure(sampledb->rbtdb));
+	return dns_db_issecure(sampledb->rbtdb);
 }
 
 static unsigned int
@@ -396,7 +396,7 @@ nodecount(dns_db_t *db, dns_dbtree_t tree) {
 
 	REQUIRE(VALID_SAMPLEDB(sampledb));
 
-	return (dns_db_nodecount(sampledb->rbtdb, tree));
+	return dns_db_nodecount(sampledb->rbtdb, tree);
 }
 
 /*
@@ -407,7 +407,7 @@ static bool
 ispersistent(dns_db_t *db) {
 	UNUSED(db);
 
-	return (true);
+	return true;
 }
 
 static void
@@ -434,7 +434,7 @@ getoriginnode(dns_db_t *db, dns_dbnode_t **nodep) {
 
 	REQUIRE(VALID_SAMPLEDB(sampledb));
 
-	return (dns_db_getoriginnode(sampledb->rbtdb, nodep));
+	return dns_db_getoriginnode(sampledb->rbtdb, nodep);
 }
 
 static void
@@ -454,8 +454,8 @@ getnsec3parameters(dns_db_t *db, dns_dbversion_t *version, dns_hash_t *hash,
 
 	REQUIRE(VALID_SAMPLEDB(sampledb));
 
-	return (dns_db_getnsec3parameters(sampledb->rbtdb, version, hash, flags,
-					  iterations, salt, salt_length));
+	return dns_db_getnsec3parameters(sampledb->rbtdb, version, hash, flags,
+					 iterations, salt, salt_length);
 }
 
 static isc_result_t
@@ -465,7 +465,7 @@ findnsec3node(dns_db_t *db, const dns_name_t *name, bool create,
 
 	REQUIRE(VALID_SAMPLEDB(sampledb));
 
-	return (dns_db_findnsec3node(sampledb->rbtdb, name, create, nodep));
+	return dns_db_findnsec3node(sampledb->rbtdb, name, create, nodep);
 }
 
 static isc_result_t
@@ -474,7 +474,7 @@ setsigningtime(dns_db_t *db, dns_rdataset_t *rdataset, isc_stdtime_t resign) {
 
 	REQUIRE(VALID_SAMPLEDB(sampledb));
 
-	return (dns_db_setsigningtime(sampledb->rbtdb, rdataset, resign));
+	return dns_db_setsigningtime(sampledb->rbtdb, rdataset, resign);
 }
 
 static isc_result_t
@@ -483,7 +483,7 @@ getsigningtime(dns_db_t *db, dns_rdataset_t *rdataset, dns_name_t *name) {
 
 	REQUIRE(VALID_SAMPLEDB(sampledb));
 
-	return (dns_db_getsigningtime(sampledb->rbtdb, rdataset, name));
+	return dns_db_getsigningtime(sampledb->rbtdb, rdataset, name);
 }
 
 static void
@@ -501,7 +501,7 @@ isdnssec(dns_db_t *db) {
 
 	REQUIRE(VALID_SAMPLEDB(sampledb));
 
-	return (dns_db_isdnssec(sampledb->rbtdb));
+	return dns_db_isdnssec(sampledb->rbtdb);
 }
 
 static dns_stats_t *
@@ -510,7 +510,7 @@ getrrsetstats(dns_db_t *db) {
 
 	REQUIRE(VALID_SAMPLEDB(sampledb));
 
-	return (dns_db_getrrsetstats(sampledb->rbtdb));
+	return dns_db_getrrsetstats(sampledb->rbtdb);
 }
 
 static isc_result_t
@@ -521,8 +521,8 @@ findnodeext(dns_db_t *db, const dns_name_t *name, bool create,
 
 	REQUIRE(VALID_SAMPLEDB(sampledb));
 
-	return (dns_db_findnodeext(sampledb->rbtdb, name, create, methods,
-				   clientinfo, nodep));
+	return dns_db_findnodeext(sampledb->rbtdb, name, create, methods,
+				  clientinfo, nodep);
 }
 
 static isc_result_t
@@ -535,9 +535,9 @@ findext(dns_db_t *db, const dns_name_t *name, dns_dbversion_t *version,
 
 	REQUIRE(VALID_SAMPLEDB(sampledb));
 
-	return (dns_db_findext(sampledb->rbtdb, name, version, type, options,
-			       now, nodep, foundname, methods, clientinfo,
-			       rdataset, sigrdataset));
+	return dns_db_findext(sampledb->rbtdb, name, version, type, options,
+			      now, nodep, foundname, methods, clientinfo,
+			      rdataset, sigrdataset);
 }
 
 static isc_result_t
@@ -546,7 +546,7 @@ setcachestats(dns_db_t *db, isc_stats_t *stats) {
 
 	REQUIRE(VALID_SAMPLEDB(sampledb));
 
-	return (dns_db_setcachestats(sampledb->rbtdb, stats));
+	return dns_db_setcachestats(sampledb->rbtdb, stats);
 }
 
 static size_t
@@ -555,7 +555,7 @@ hashsize(dns_db_t *db) {
 
 	REQUIRE(VALID_SAMPLEDB(sampledb));
 
-	return (dns_db_hashsize(sampledb->rbtdb));
+	return dns_db_hashsize(sampledb->rbtdb);
 }
 
 /*
@@ -653,7 +653,7 @@ cleanup:
 	if (node != NULL) {
 		dns_db_detachnode(db, &node);
 	}
-	return (result);
+	return result;
 }
 
 static isc_result_t
@@ -691,7 +691,7 @@ cleanup:
 	if (node != NULL) {
 		dns_db_detachnode(db, &node);
 	}
-	return (result);
+	return result;
 }
 
 static isc_result_t
@@ -727,7 +727,7 @@ cleanup:
 	if (node != NULL) {
 		dns_db_detachnode(db, &node);
 	}
-	return (result);
+	return result;
 }
 
 /*
@@ -789,7 +789,7 @@ create_db(isc_mem_t *mctx, const dns_name_t *origin, dns_dbtype_t type,
 
 	*dbp = (dns_db_t *)sampledb;
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 
 cleanup:
 	if (sampledb != NULL) {
@@ -801,5 +801,5 @@ cleanup:
 				     sizeof(*sampledb));
 	}
 
-	return (result);
+	return result;
 }
