@@ -87,7 +87,6 @@ def token_init_and_cleanup():
             raise_on_exception=False,
         ).stdout.decode("utf-8")
         assert re.search("Found token (.*) with matching token label", output)
-        assert re.search("The token (.*) has been deleted", output)
 
 
 # pylint: disable-msg=too-many-locals
@@ -142,6 +141,7 @@ def test_keyfromlabel(alg_name, alg_type, alg_bits):
             "pkcs11",
             "-a",
             alg_name,
+            "-y",
             "-l",
             f"pkcs11:token=softhsm2-keyfromlabel;object={key_id}-{zone};pin-source=pin",
             *key_flag,
