@@ -50,7 +50,7 @@
 		if ((x) != ISC_R_SUCCESS) {                  \
 			fprintf(stderr, "I:%s: %s\n", (str), \
 				isc_result_totext(x));       \
-			exit(-1);                            \
+			exit(EXIT_FAILURE);                  \
 		}                                            \
 	}
 
@@ -82,7 +82,7 @@ recvresponse(isc_task_t *task, isc_event_t *event) {
 	if (reqev->result != ISC_R_SUCCESS) {
 		fprintf(stderr, "I:request event result: %s\n",
 			isc_result_totext(reqev->result));
-		exit(-1);
+		exit(EXIT_FAILURE);
 	}
 
 	query = reqev->ev_arg;
@@ -97,7 +97,7 @@ recvresponse(isc_task_t *task, isc_event_t *event) {
 		result = dns_result_fromrcode(response->rcode);
 		fprintf(stderr, "I:response rcode: %s\n",
 			isc_result_totext(result));
-		exit(-1);
+		exit(EXIT_FAILURE);
 	}
 	if (response->counts[DNS_SECTION_ANSWER] != 1U) {
 		fprintf(stderr, "I:response answer count (%u!=1)\n",
@@ -138,7 +138,7 @@ sendquery(isc_task_t *task) {
 
 	c = scanf("%255s", host);
 	if (c == EOF) {
-		return (ISC_R_NOMORE);
+		return ISC_R_NOMORE;
 	}
 
 	onfly++;
@@ -170,12 +170,12 @@ sendquery(isc_task_t *task) {
 	dns_message_addname(message, qname, DNS_SECTION_QUESTION);
 
 	result = dns_request_create(requestmgr, message,
-				    have_src ? &srcaddr : NULL, &dstaddr, -1,
+				    have_src ? &srcaddr : NULL, &dstaddr,
 				    DNS_REQUESTOPT_TCP, NULL, TIMEOUT, 0, 0,
 				    task, recvresponse, message, &request);
 	CHECK("dns_request_create", result);
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static void
@@ -221,7 +221,7 @@ main(int argc, char *argv[]) {
 			if (result != ISC_R_SUCCESS) {
 				fprintf(stderr, "bad port '%s'\n",
 					isc_commandline_argument);
-				exit(1);
+				exit(EXIT_FAILURE);
 			}
 			break;
 		case 'r':
@@ -299,5 +299,5 @@ main(int argc, char *argv[]) {
 
 	isc_app_finish();
 
-	return (0);
+	return 0;
 }
