@@ -35,6 +35,7 @@
 #include <dns/log.h>
 #include <dns/master.h>
 #include <dns/rdata.h>
+#include <dns/rdataclass.h>
 #include <dns/rdataset.h>
 #include <dns/rdatasetiter.h>
 
@@ -90,10 +91,10 @@ impfind(const char *name) {
 	     imp = ISC_LIST_NEXT(imp, link))
 	{
 		if (strcasecmp(name, imp->name) == 0) {
-			return (imp);
+			return imp;
 		}
 	}
-	return (NULL);
+	return NULL;
 }
 
 /***
@@ -122,7 +123,7 @@ dns_db_create(isc_mem_t *mctx, const char *db_type, const dns_name_t *origin,
 		result = ((impinfo->create)(mctx, origin, type, rdclass, argc,
 					    argv, impinfo->driverarg, dbp));
 		RWUNLOCK(&implock, isc_rwlocktype_read);
-		return (result);
+		return result;
 	}
 
 	RWUNLOCK(&implock, isc_rwlocktype_read);
@@ -130,7 +131,7 @@ dns_db_create(isc_mem_t *mctx, const char *db_type, const dns_name_t *origin,
 	isc_log_write(dns_lctx, DNS_LOGCATEGORY_DATABASE, DNS_LOGMODULE_DB,
 		      ISC_LOG_ERROR, "unsupported database type '%s'", db_type);
 
-	return (ISC_R_NOTFOUND);
+	return ISC_R_NOTFOUND;
 }
 
 void
@@ -170,10 +171,10 @@ dns_db_iscache(dns_db_t *db) {
 	REQUIRE(DNS_DB_VALID(db));
 
 	if ((db->attributes & DNS_DBATTR_CACHE) != 0) {
-		return (true);
+		return true;
 	}
 
-	return (false);
+	return false;
 }
 
 bool
@@ -185,10 +186,10 @@ dns_db_iszone(dns_db_t *db) {
 	REQUIRE(DNS_DB_VALID(db));
 
 	if ((db->attributes & (DNS_DBATTR_CACHE | DNS_DBATTR_STUB)) == 0) {
-		return (true);
+		return true;
 	}
 
-	return (false);
+	return false;
 }
 
 bool
@@ -200,10 +201,10 @@ dns_db_isstub(dns_db_t *db) {
 	REQUIRE(DNS_DB_VALID(db));
 
 	if ((db->attributes & DNS_DBATTR_STUB) != 0) {
-		return (true);
+		return true;
 	}
 
-	return (false);
+	return false;
 }
 
 bool
@@ -216,9 +217,9 @@ dns_db_isdnssec(dns_db_t *db) {
 	REQUIRE((db->attributes & DNS_DBATTR_CACHE) == 0);
 
 	if (db->methods->isdnssec != NULL) {
-		return ((db->methods->isdnssec)(db));
+		return (db->methods->isdnssec)(db);
 	}
-	return ((db->methods->issecure)(db));
+	return (db->methods->issecure)(db);
 }
 
 bool
@@ -230,7 +231,7 @@ dns_db_issecure(dns_db_t *db) {
 	REQUIRE(DNS_DB_VALID(db));
 	REQUIRE((db->attributes & DNS_DBATTR_CACHE) == 0);
 
-	return ((db->methods->issecure)(db));
+	return (db->methods->issecure)(db);
 }
 
 bool
@@ -241,7 +242,7 @@ dns_db_ispersistent(dns_db_t *db) {
 
 	REQUIRE(DNS_DB_VALID(db));
 
-	return ((db->methods->ispersistent)(db));
+	return (db->methods->ispersistent)(db);
 }
 
 dns_name_t *
@@ -252,7 +253,7 @@ dns_db_origin(dns_db_t *db) {
 
 	REQUIRE(DNS_DB_VALID(db));
 
-	return (&db->origin);
+	return &db->origin;
 }
 
 dns_rdataclass_t
@@ -263,7 +264,7 @@ dns_db_class(dns_db_t *db) {
 
 	REQUIRE(DNS_DB_VALID(db));
 
-	return (db->rdclass);
+	return db->rdclass;
 }
 
 isc_result_t
@@ -275,7 +276,7 @@ dns_db_beginload(dns_db_t *db, dns_rdatacallbacks_t *callbacks) {
 	REQUIRE(DNS_DB_VALID(db));
 	REQUIRE(DNS_CALLBACK_VALID(callbacks));
 
-	return ((db->methods->beginload)(db, callbacks));
+	return (db->methods->beginload)(db, callbacks);
 }
 
 isc_result_t
@@ -296,7 +297,7 @@ dns_db_endload(dns_db_t *db, dns_rdatacallbacks_t *callbacks) {
 		listener->onupdate(db, listener->onupdate_arg);
 	}
 
-	return ((db->methods->endload)(db, callbacks));
+	return (db->methods->endload)(db, callbacks);
 }
 
 isc_result_t
@@ -318,7 +319,7 @@ dns_db_load(dns_db_t *db, const char *filename, dns_masterformat_t format,
 	dns_rdatacallbacks_init(&callbacks);
 	result = dns_db_beginload(db, &callbacks);
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		return result;
 	}
 	result = dns_master_loadfile(filename, &db->origin, &db->origin,
 				     db->rdclass, options, 0, &callbacks, NULL,
@@ -335,13 +336,13 @@ dns_db_load(dns_db_t *db, const char *filename, dns_masterformat_t format,
 		result = eresult;
 	}
 
-	return (result);
+	return result;
 }
 
 isc_result_t
 dns_db_dump(dns_db_t *db, dns_dbversion_t *version, const char *filename) {
-	return ((db->methods->dump)(db, version, filename,
-				    dns_masterformat_text));
+	return (db->methods->dump)(db, version, filename,
+				   dns_masterformat_text);
 }
 
 /***
@@ -371,7 +372,7 @@ dns_db_newversion(dns_db_t *db, dns_dbversion_t **versionp) {
 	REQUIRE((db->attributes & DNS_DBATTR_CACHE) == 0);
 	REQUIRE(versionp != NULL && *versionp == NULL);
 
-	return ((db->methods->newversion)(db, versionp));
+	return (db->methods->newversion)(db, versionp);
 }
 
 void
@@ -431,10 +432,10 @@ dns_db_findnode(dns_db_t *db, const dns_name_t *name, bool create,
 	REQUIRE(nodep != NULL && *nodep == NULL);
 
 	if (db->methods->findnode != NULL) {
-		return ((db->methods->findnode)(db, name, create, nodep));
+		return (db->methods->findnode)(db, name, create, nodep);
 	} else {
-		return ((db->methods->findnodeext)(db, name, create, NULL, NULL,
-						   nodep));
+		return (db->methods->findnodeext)(db, name, create, NULL, NULL,
+						  nodep);
 	}
 }
 
@@ -451,10 +452,10 @@ dns_db_findnodeext(dns_db_t *db, const dns_name_t *name, bool create,
 	REQUIRE(nodep != NULL && *nodep == NULL);
 
 	if (db->methods->findnodeext != NULL) {
-		return ((db->methods->findnodeext)(db, name, create, methods,
-						   clientinfo, nodep));
+		return (db->methods->findnodeext)(db, name, create, methods,
+						  clientinfo, nodep);
 	} else {
-		return ((db->methods->findnode)(db, name, create, nodep));
+		return (db->methods->findnode)(db, name, create, nodep);
 	}
 }
 
@@ -468,7 +469,7 @@ dns_db_findnsec3node(dns_db_t *db, const dns_name_t *name, bool create,
 	REQUIRE(DNS_DB_VALID(db));
 	REQUIRE(nodep != NULL && *nodep == NULL);
 
-	return ((db->methods->findnsec3node)(db, name, create, nodep));
+	return (db->methods->findnsec3node)(db, name, create, nodep);
 }
 
 isc_result_t
@@ -492,13 +493,13 @@ dns_db_find(dns_db_t *db, const dns_name_t *name, dns_dbversion_t *version,
 		 !dns_rdataset_isassociated(sigrdataset)));
 
 	if (db->methods->find != NULL) {
-		return ((db->methods->find)(db, name, version, type, options,
-					    now, nodep, foundname, rdataset,
-					    sigrdataset));
+		return (db->methods->find)(db, name, version, type, options,
+					   now, nodep, foundname, rdataset,
+					   sigrdataset);
 	} else {
-		return ((db->methods->findext)(db, name, version, type, options,
-					       now, nodep, foundname, NULL,
-					       NULL, rdataset, sigrdataset));
+		return (db->methods->findext)(db, name, version, type, options,
+					      now, nodep, foundname, NULL, NULL,
+					      rdataset, sigrdataset);
 	}
 }
 
@@ -524,13 +525,13 @@ dns_db_findext(dns_db_t *db, const dns_name_t *name, dns_dbversion_t *version,
 		 !dns_rdataset_isassociated(sigrdataset)));
 
 	if (db->methods->findext != NULL) {
-		return ((db->methods->findext)(
+		return (db->methods->findext)(
 			db, name, version, type, options, now, nodep, foundname,
-			methods, clientinfo, rdataset, sigrdataset));
+			methods, clientinfo, rdataset, sigrdataset);
 	} else {
-		return ((db->methods->find)(db, name, version, type, options,
-					    now, nodep, foundname, rdataset,
-					    sigrdataset));
+		return (db->methods->find)(db, name, version, type, options,
+					   now, nodep, foundname, rdataset,
+					   sigrdataset);
 	}
 }
 
@@ -553,9 +554,9 @@ dns_db_findzonecut(dns_db_t *db, const dns_name_t *name, unsigned int options,
 		(DNS_RDATASET_VALID(sigrdataset) &&
 		 !dns_rdataset_isassociated(sigrdataset)));
 
-	return ((db->methods->findzonecut)(db, name, options, now, nodep,
-					   foundname, dcname, rdataset,
-					   sigrdataset));
+	return (db->methods->findzonecut)(db, name, options, now, nodep,
+					  foundname, dcname, rdataset,
+					  sigrdataset);
 }
 
 void
@@ -619,7 +620,7 @@ dns_db_expirenode(dns_db_t *db, dns_dbnode_t *node, isc_stdtime_t now) {
 	REQUIRE((db->attributes & DNS_DBATTR_CACHE) != 0);
 	REQUIRE(node != NULL);
 
-	return ((db->methods->expirenode)(db, node, now));
+	return (db->methods->expirenode)(db, node, now);
 }
 
 void
@@ -651,7 +652,7 @@ dns_db_createiterator(dns_db_t *db, unsigned int flags,
 	REQUIRE((flags & (DNS_DB_NSEC3ONLY | DNS_DB_NONSEC3)) !=
 		(DNS_DB_NSEC3ONLY | DNS_DB_NONSEC3));
 
-	return (db->methods->createiterator(db, flags, iteratorp));
+	return db->methods->createiterator(db, flags, iteratorp);
 }
 
 /***
@@ -673,8 +674,8 @@ dns_db_findrdataset(dns_db_t *db, dns_dbnode_t *node, dns_dbversion_t *version,
 		(DNS_RDATASET_VALID(sigrdataset) &&
 		 !dns_rdataset_isassociated(sigrdataset)));
 
-	return ((db->methods->findrdataset)(db, node, version, type, covers,
-					    now, rdataset, sigrdataset));
+	return (db->methods->findrdataset)(db, node, version, type, covers, now,
+					   rdataset, sigrdataset);
 }
 
 isc_result_t
@@ -689,8 +690,8 @@ dns_db_allrdatasets(dns_db_t *db, dns_dbnode_t *node, dns_dbversion_t *version,
 	REQUIRE(DNS_DB_VALID(db));
 	REQUIRE(iteratorp != NULL && *iteratorp == NULL);
 
-	return ((db->methods->allrdatasets)(db, node, version, options, now,
-					    iteratorp));
+	return (db->methods->allrdatasets)(db, node, version, options, now,
+					   iteratorp);
 }
 
 isc_result_t
@@ -715,8 +716,8 @@ dns_db_addrdataset(dns_db_t *db, dns_dbnode_t *node, dns_dbversion_t *version,
 		(DNS_RDATASET_VALID(addedrdataset) &&
 		 !dns_rdataset_isassociated(addedrdataset)));
 
-	return ((db->methods->addrdataset)(db, node, version, now, rdataset,
-					   options, addedrdataset));
+	return (db->methods->addrdataset)(db, node, version, now, rdataset,
+					  options, addedrdataset);
 }
 
 isc_result_t
@@ -738,8 +739,8 @@ dns_db_subtractrdataset(dns_db_t *db, dns_dbnode_t *node,
 		(DNS_RDATASET_VALID(newrdataset) &&
 		 !dns_rdataset_isassociated(newrdataset)));
 
-	return ((db->methods->subtractrdataset)(db, node, version, rdataset,
-						options, newrdataset));
+	return (db->methods->subtractrdataset)(db, node, version, rdataset,
+					       options, newrdataset);
 }
 
 isc_result_t
@@ -756,7 +757,7 @@ dns_db_deleterdataset(dns_db_t *db, dns_dbnode_t *node,
 	REQUIRE(((db->attributes & DNS_DBATTR_CACHE) == 0 && version != NULL) ||
 		((db->attributes & DNS_DBATTR_CACHE) != 0 && version == NULL));
 
-	return ((db->methods->deleterdataset)(db, node, version, type, covers));
+	return (db->methods->deleterdataset)(db, node, version, type, covers);
 }
 
 void
@@ -778,7 +779,7 @@ dns_db_getsoaserial(dns_db_t *db, dns_dbversion_t *ver, uint32_t *serialp) {
 
 	result = dns_db_findnode(db, dns_db_origin(db), false, &node);
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		return result;
 	}
 
 	dns_rdataset_init(&rdataset);
@@ -809,14 +810,14 @@ freerdataset:
 
 freenode:
 	dns_db_detachnode(db, &node);
-	return (result);
+	return result;
 }
 
 unsigned int
 dns_db_nodecount(dns_db_t *db, dns_dbtree_t tree) {
 	REQUIRE(DNS_DB_VALID(db));
 
-	return ((db->methods->nodecount)(db, tree));
+	return (db->methods->nodecount)(db, tree);
 }
 
 size_t
@@ -824,10 +825,10 @@ dns_db_hashsize(dns_db_t *db) {
 	REQUIRE(DNS_DB_VALID(db));
 
 	if (db->methods->hashsize == NULL) {
-		return (0);
+		return 0;
 	}
 
-	return ((db->methods->hashsize)(db));
+	return (db->methods->hashsize)(db);
 }
 
 void
@@ -851,7 +852,7 @@ dns_db_register(const char *name, dns_dbcreatefunc_t create, void *driverarg,
 	imp = impfind(name);
 	if (imp != NULL) {
 		RWUNLOCK(&implock, isc_rwlocktype_write);
-		return (ISC_R_EXISTS);
+		return ISC_R_EXISTS;
 	}
 
 	imp = isc_mem_get(mctx, sizeof(dns_dbimplementation_t));
@@ -866,7 +867,7 @@ dns_db_register(const char *name, dns_dbcreatefunc_t create, void *driverarg,
 
 	*dbimp = imp;
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 void
@@ -893,10 +894,10 @@ dns_db_getoriginnode(dns_db_t *db, dns_dbnode_t **nodep) {
 	REQUIRE(nodep != NULL && *nodep == NULL);
 
 	if (db->methods->getoriginnode != NULL) {
-		return ((db->methods->getoriginnode)(db, nodep));
+		return (db->methods->getoriginnode)(db, nodep);
 	}
 
-	return (ISC_R_NOTFOUND);
+	return ISC_R_NOTFOUND;
 }
 
 dns_stats_t *
@@ -904,10 +905,10 @@ dns_db_getrrsetstats(dns_db_t *db) {
 	REQUIRE(DNS_DB_VALID(db));
 
 	if (db->methods->getrrsetstats != NULL) {
-		return ((db->methods->getrrsetstats)(db));
+		return (db->methods->getrrsetstats)(db);
 	}
 
-	return (NULL);
+	return NULL;
 }
 
 isc_result_t
@@ -915,10 +916,10 @@ dns_db_setcachestats(dns_db_t *db, isc_stats_t *stats) {
 	REQUIRE(DNS_DB_VALID(db));
 
 	if (db->methods->setcachestats != NULL) {
-		return ((db->methods->setcachestats)(db, stats));
+		return (db->methods->setcachestats)(db, stats);
 	}
 
-	return (ISC_R_NOTIMPLEMENTED);
+	return ISC_R_NOTIMPLEMENTED;
 }
 
 isc_result_t
@@ -930,12 +931,12 @@ dns_db_getnsec3parameters(dns_db_t *db, dns_dbversion_t *version,
 	REQUIRE(dns_db_iszone(db));
 
 	if (db->methods->getnsec3parameters != NULL) {
-		return ((db->methods->getnsec3parameters)(db, version, hash,
-							  flags, iterations,
-							  salt, salt_length));
+		return (db->methods->getnsec3parameters)(db, version, hash,
+							 flags, iterations,
+							 salt, salt_length);
 	}
 
-	return (ISC_R_NOTFOUND);
+	return ISC_R_NOTFOUND;
 }
 
 isc_result_t
@@ -945,28 +946,28 @@ dns_db_getsize(dns_db_t *db, dns_dbversion_t *version, uint64_t *records,
 	REQUIRE(dns_db_iszone(db));
 
 	if (db->methods->getsize != NULL) {
-		return ((db->methods->getsize)(db, version, records, bytes));
+		return (db->methods->getsize)(db, version, records, bytes);
 	}
 
-	return (ISC_R_NOTFOUND);
+	return ISC_R_NOTFOUND;
 }
 
 isc_result_t
 dns_db_setsigningtime(dns_db_t *db, dns_rdataset_t *rdataset,
 		      isc_stdtime_t resign) {
 	if (db->methods->setsigningtime != NULL) {
-		return ((db->methods->setsigningtime)(db, rdataset, resign));
+		return (db->methods->setsigningtime)(db, rdataset, resign);
 	}
-	return (ISC_R_NOTIMPLEMENTED);
+	return ISC_R_NOTIMPLEMENTED;
 }
 
 isc_result_t
 dns_db_getsigningtime(dns_db_t *db, dns_rdataset_t *rdataset,
 		      dns_name_t *name) {
 	if (db->methods->getsigningtime != NULL) {
-		return ((db->methods->getsigningtime)(db, rdataset, name));
+		return (db->methods->getsigningtime)(db, rdataset, name);
 	}
-	return (ISC_R_NOTFOUND);
+	return ISC_R_NOTFOUND;
 }
 
 void
@@ -994,9 +995,9 @@ dns_db_rpz_attach(dns_db_t *db, void *rpzs, uint8_t rpz_num) {
 isc_result_t
 dns_db_rpz_ready(dns_db_t *db) {
 	if (db->methods->rpz_ready == NULL) {
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
-	return ((db->methods->rpz_ready)(db));
+	return (db->methods->rpz_ready)(db);
 }
 
 /*
@@ -1016,7 +1017,7 @@ dns_db_updatenotify_register(dns_db_t *db, dns_dbupdate_callback_t fn,
 		if ((listener->onupdate == fn) &&
 		    (listener->onupdate_arg == fn_arg))
 		{
-			return (ISC_R_SUCCESS);
+			return ISC_R_SUCCESS;
 		}
 	}
 
@@ -1028,7 +1029,7 @@ dns_db_updatenotify_register(dns_db_t *db, dns_dbupdate_callback_t fn,
 	ISC_LINK_INIT(listener, link);
 	ISC_LIST_APPEND(db->update_listeners, listener, link);
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 isc_result_t
@@ -1047,11 +1048,11 @@ dns_db_updatenotify_unregister(dns_db_t *db, dns_dbupdate_callback_t fn,
 			ISC_LIST_UNLINK(db->update_listeners, listener, link);
 			isc_mem_put(db->mctx, listener,
 				    sizeof(dns_dbonupdatelistener_t));
-			return (ISC_R_SUCCESS);
+			return ISC_R_SUCCESS;
 		}
 	}
 
-	return (ISC_R_NOTFOUND);
+	return ISC_R_NOTFOUND;
 }
 
 isc_result_t
@@ -1061,9 +1062,9 @@ dns_db_nodefullname(dns_db_t *db, dns_dbnode_t *node, dns_name_t *name) {
 	REQUIRE(name != NULL);
 
 	if (db->methods->nodefullname == NULL) {
-		return (ISC_R_NOTIMPLEMENTED);
+		return ISC_R_NOTIMPLEMENTED;
 	}
-	return ((db->methods->nodefullname)(db, node, name));
+	return (db->methods->nodefullname)(db, node, name);
 }
 
 isc_result_t
@@ -1072,9 +1073,9 @@ dns_db_setservestalettl(dns_db_t *db, dns_ttl_t ttl) {
 	REQUIRE((db->attributes & DNS_DBATTR_CACHE) != 0);
 
 	if (db->methods->setservestalettl != NULL) {
-		return ((db->methods->setservestalettl)(db, ttl));
+		return (db->methods->setservestalettl)(db, ttl);
 	}
-	return (ISC_R_NOTIMPLEMENTED);
+	return ISC_R_NOTIMPLEMENTED;
 }
 
 isc_result_t
@@ -1083,9 +1084,9 @@ dns_db_getservestalettl(dns_db_t *db, dns_ttl_t *ttl) {
 	REQUIRE((db->attributes & DNS_DBATTR_CACHE) != 0);
 
 	if (db->methods->getservestalettl != NULL) {
-		return ((db->methods->getservestalettl)(db, ttl));
+		return (db->methods->getservestalettl)(db, ttl);
 	}
-	return (ISC_R_NOTIMPLEMENTED);
+	return ISC_R_NOTIMPLEMENTED;
 }
 
 isc_result_t
@@ -1094,9 +1095,9 @@ dns_db_setservestalerefresh(dns_db_t *db, uint32_t interval) {
 	REQUIRE((db->attributes & DNS_DBATTR_CACHE) != 0);
 
 	if (db->methods->setservestalerefresh != NULL) {
-		return ((db->methods->setservestalerefresh)(db, interval));
+		return (db->methods->setservestalerefresh)(db, interval);
 	}
-	return (ISC_R_NOTIMPLEMENTED);
+	return ISC_R_NOTIMPLEMENTED;
 }
 
 isc_result_t
@@ -1105,9 +1106,9 @@ dns_db_getservestalerefresh(dns_db_t *db, uint32_t *interval) {
 	REQUIRE((db->attributes & DNS_DBATTR_CACHE) != 0);
 
 	if (db->methods->getservestalerefresh != NULL) {
-		return ((db->methods->getservestalerefresh)(db, interval));
+		return (db->methods->getservestalerefresh)(db, interval);
 	}
-	return (ISC_R_NOTIMPLEMENTED);
+	return ISC_R_NOTIMPLEMENTED;
 }
 
 isc_result_t
@@ -1116,10 +1117,10 @@ dns_db_setgluecachestats(dns_db_t *db, isc_stats_t *stats) {
 	REQUIRE(stats != NULL);
 
 	if (db->methods->setgluecachestats != NULL) {
-		return ((db->methods->setgluecachestats)(db, stats));
+		return (db->methods->setgluecachestats)(db, stats);
 	}
 
-	return (ISC_R_NOTIMPLEMENTED);
+	return ISC_R_NOTIMPLEMENTED;
 }
 
 void
@@ -1139,3 +1140,26 @@ dns_db_setmaxtypepername(dns_db_t *db, uint32_t value) {
 		(db->methods->setmaxtypepername)(db, value);
 	}
 }
+
+void
+dns__db_logtoomanyrecords(dns_db_t *db, const dns_name_t *name,
+			  dns_rdatatype_t type, const char *op,
+			  uint32_t limit) {
+	char namebuf[DNS_NAME_FORMATSIZE];
+	char originbuf[DNS_NAME_FORMATSIZE];
+	char typebuf[DNS_RDATATYPE_FORMATSIZE];
+	char clsbuf[DNS_RDATACLASS_FORMATSIZE];
+
+	dns_name_format(name, namebuf, sizeof(namebuf));
+	dns_name_format(&db->origin, originbuf, sizeof(originbuf));
+	dns_rdatatype_format(type, typebuf, sizeof(typebuf));
+	dns_rdataclass_format(db->rdclass, clsbuf, sizeof(clsbuf));
+
+	isc_log_write(
+		dns_lctx, DNS_LOGCATEGORY_DATABASE, DNS_LOGMODULE_DB,
+		ISC_LOG_ERROR,
+		"error %s '%s/%s' in '%s/%s' (%s): %s (must not exceed %u)", op,
+		namebuf, typebuf, originbuf, clsbuf,
+		(db->attributes & DNS_DBATTR_CACHE) != 0 ? "cache" : "zone",
+		isc_result_totext(DNS_R_TOOMANYRECORDS), limit);
+}
