@@ -30,11 +30,11 @@
 #include "dst_parse.h"
 #include <inttypes.h>
 #include <stdbool.h>
+#include <unistd.h>
 
 #include <isc/base64.h>
 #include <isc/dir.h>
 #include <isc/file.h>
-#include <isc/fsaccess.h>
 #include <isc/lex.h>
 #include <isc/mem.h>
 #include <isc/print.h>
@@ -124,10 +124,10 @@ find_value(const char *s, const unsigned int alg) {
 		if (strcasecmp(s, map[i].tag) == 0 &&
 		    (TAG_ALG(map[i].value) == alg))
 		{
-			return (map[i].value);
+			return map[i].value;
 		}
 	}
-	return (-1);
+	return -1;
 }
 
 static const char *
@@ -136,9 +136,9 @@ find_tag(const int value) {
 
 	for (i = 0;; i++) {
 		if (map[i].tag == NULL) {
-			return (NULL);
+			return NULL;
 		} else if (value == map[i].value) {
-			return (map[i].tag);
+			return map[i].tag;
 		}
 	}
 }
@@ -149,21 +149,21 @@ find_metadata(const char *s, const char *tags[], int ntags) {
 
 	for (i = 0; i < ntags; i++) {
 		if (tags[i] != NULL && strcasecmp(s, tags[i]) == 0) {
-			return (i);
+			return i;
 		}
 	}
 
-	return (-1);
+	return -1;
 }
 
 static int
 find_timedata(const char *s) {
-	return (find_metadata(s, timetags, TIMING_NTAGS));
+	return find_metadata(s, timetags, TIMING_NTAGS);
 }
 
 static int
 find_numericdata(const char *s) {
-	return (find_metadata(s, numerictags, NUMERIC_NTAGS));
+	return find_metadata(s, numerictags, NUMERIC_NTAGS);
 }
 
 static int
@@ -174,7 +174,7 @@ check_rsa(const dst_private_t *priv, bool external) {
 	unsigned int mask;
 
 	if (external) {
-		return ((priv->nelements == 0) ? 0 : -1);
+		return (priv->nelements == 0) ? 0 : -1;
 	}
 
 	for (i = 0; i < RSA_NTAGS; i++) {
@@ -188,7 +188,7 @@ check_rsa(const dst_private_t *priv, bool external) {
 			}
 		}
 		if (i == RSA_NTAGS) {
-			return (-1);
+			return -1;
 		}
 		have[i] = true;
 	}
@@ -209,14 +209,14 @@ check_rsa(const dst_private_t *priv, bool external) {
 		     have[TAG_RSA_EXPONENT2 & mask] &&
 		     have[TAG_RSA_COEFFICIENT & mask];
 	}
-	return (ok ? 0 : -1);
+	return ok ? 0 : -1;
 }
 
 static int
 check_dh(const dst_private_t *priv) {
 	int i, j;
 	if (priv->nelements != DH_NTAGS) {
-		return (-1);
+		return -1;
 	}
 	for (i = 0; i < DH_NTAGS; i++) {
 		for (j = 0; j < priv->nelements; j++) {
@@ -225,10 +225,10 @@ check_dh(const dst_private_t *priv) {
 			}
 		}
 		if (j == priv->nelements) {
-			return (-1);
+			return -1;
 		}
 	}
-	return (0);
+	return 0;
 }
 
 static int
@@ -239,7 +239,7 @@ check_ecdsa(const dst_private_t *priv, bool external) {
 	unsigned int mask;
 
 	if (external) {
-		return ((priv->nelements == 0) ? 0 : -1);
+		return (priv->nelements == 0) ? 0 : -1;
 	}
 
 	for (i = 0; i < ECDSA_NTAGS; i++) {
@@ -252,7 +252,7 @@ check_ecdsa(const dst_private_t *priv, bool external) {
 			}
 		}
 		if (i == ECDSA_NTAGS) {
-			return (-1);
+			return -1;
 		}
 		have[i] = true;
 	}
@@ -264,7 +264,7 @@ check_ecdsa(const dst_private_t *priv, bool external) {
 	} else {
 		ok = have[TAG_ECDSA_PRIVATEKEY & mask];
 	}
-	return (ok ? 0 : -1);
+	return ok ? 0 : -1;
 }
 
 static int
@@ -275,7 +275,7 @@ check_eddsa(const dst_private_t *priv, bool external) {
 	unsigned int mask;
 
 	if (external) {
-		return ((priv->nelements == 0) ? 0 : -1);
+		return (priv->nelements == 0) ? 0 : -1;
 	}
 
 	for (i = 0; i < EDDSA_NTAGS; i++) {
@@ -288,7 +288,7 @@ check_eddsa(const dst_private_t *priv, bool external) {
 			}
 		}
 		if (i == EDDSA_NTAGS) {
-			return (-1);
+			return -1;
 		}
 		have[i] = true;
 	}
@@ -300,7 +300,7 @@ check_eddsa(const dst_private_t *priv, bool external) {
 	} else {
 		ok = have[TAG_EDDSA_PRIVATEKEY & mask];
 	}
-	return (ok ? 0 : -1);
+	return ok ? 0 : -1;
 }
 
 static int
@@ -315,9 +315,9 @@ check_hmac_md5(const dst_private_t *priv, bool old) {
 		if (old && priv->nelements == OLD_HMACMD5_NTAGS &&
 		    priv->elements[0].tag == TAG_HMACMD5_KEY)
 		{
-			return (0);
+			return 0;
 		}
-		return (-1);
+		return -1;
 	}
 	/*
 	 * We must be new format at this point.
@@ -329,10 +329,10 @@ check_hmac_md5(const dst_private_t *priv, bool old) {
 			}
 		}
 		if (j == priv->nelements) {
-			return (-1);
+			return -1;
 		}
 	}
-	return (0);
+	return 0;
 }
 
 static int
@@ -340,7 +340,7 @@ check_hmac_sha(const dst_private_t *priv, unsigned int ntags,
 	       unsigned int alg) {
 	unsigned int i, j;
 	if (priv->nelements != ntags) {
-		return (-1);
+		return -1;
 	}
 	for (i = 0; i < ntags; i++) {
 		for (j = 0; j < priv->nelements; j++) {
@@ -349,10 +349,10 @@ check_hmac_sha(const dst_private_t *priv, unsigned int ntags,
 			}
 		}
 		if (j == priv->nelements) {
-			return (-1);
+			return -1;
 		}
 	}
-	return (0);
+	return 0;
 }
 
 static int
@@ -365,29 +365,29 @@ check_data(const dst_private_t *priv, const unsigned int alg, bool old,
 	case DST_ALG_NSEC3RSASHA1:
 	case DST_ALG_RSASHA256:
 	case DST_ALG_RSASHA512:
-		return (check_rsa(priv, external));
+		return check_rsa(priv, external);
 	case DST_ALG_DH:
-		return (check_dh(priv));
+		return check_dh(priv);
 	case DST_ALG_ECDSA256:
 	case DST_ALG_ECDSA384:
-		return (check_ecdsa(priv, external));
+		return check_ecdsa(priv, external);
 	case DST_ALG_ED25519:
 	case DST_ALG_ED448:
-		return (check_eddsa(priv, external));
+		return check_eddsa(priv, external);
 	case DST_ALG_HMACMD5:
-		return (check_hmac_md5(priv, old));
+		return check_hmac_md5(priv, old);
 	case DST_ALG_HMACSHA1:
-		return (check_hmac_sha(priv, HMACSHA1_NTAGS, alg));
+		return check_hmac_sha(priv, HMACSHA1_NTAGS, alg);
 	case DST_ALG_HMACSHA224:
-		return (check_hmac_sha(priv, HMACSHA224_NTAGS, alg));
+		return check_hmac_sha(priv, HMACSHA224_NTAGS, alg);
 	case DST_ALG_HMACSHA256:
-		return (check_hmac_sha(priv, HMACSHA256_NTAGS, alg));
+		return check_hmac_sha(priv, HMACSHA256_NTAGS, alg);
 	case DST_ALG_HMACSHA384:
-		return (check_hmac_sha(priv, HMACSHA384_NTAGS, alg));
+		return check_hmac_sha(priv, HMACSHA384_NTAGS, alg);
 	case DST_ALG_HMACSHA512:
-		return (check_hmac_sha(priv, HMACSHA512_NTAGS, alg));
+		return check_hmac_sha(priv, HMACSHA512_NTAGS, alg);
 	default:
-		return (DST_R_UNSUPPORTEDALG);
+		return DST_R_UNSUPPORTEDALG;
 	}
 }
 
@@ -604,7 +604,7 @@ done:
 
 	key->external = external;
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 
 fail:
 	dst__privstruct_free(priv, mctx);
@@ -612,7 +612,7 @@ fail:
 		isc_mem_put(mctx, data, MAXFIELDSIZE);
 	}
 
-	return (ret);
+	return ret;
 }
 
 isc_result_t
@@ -621,11 +621,13 @@ dst__privstruct_writefile(const dst_key_t *key, const dst_private_t *priv,
 	FILE *fp;
 	isc_result_t result;
 	char filename[NAME_MAX];
+	char tmpname[NAME_MAX];
 	char buffer[MAXFIELDSIZE * 2];
-	isc_fsaccess_t access;
 	isc_stdtime_t when;
 	uint32_t value;
 	isc_buffer_t b;
+	isc_buffer_t fileb;
+	isc_buffer_t tmpb;
 	isc_region_t r;
 	int major, minor;
 	mode_t mode;
@@ -635,19 +637,20 @@ dst__privstruct_writefile(const dst_key_t *key, const dst_private_t *priv,
 
 	ret = check_data(priv, dst_key_alg(key), false, key->external);
 	if (ret < 0) {
-		return (DST_R_INVALIDPRIVATEKEY);
+		return DST_R_INVALIDPRIVATEKEY;
 	} else if (ret != ISC_R_SUCCESS) {
-		return (ret);
+		return ret;
 	}
 
-	isc_buffer_init(&b, filename, sizeof(filename));
-	result = dst_key_buildfilename(key, DST_TYPE_PRIVATE, directory, &b);
+	isc_buffer_init(&fileb, filename, sizeof(filename));
+	result = dst_key_buildfilename(key, DST_TYPE_PRIVATE, directory,
+				       &fileb);
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		return result;
 	}
 
 	result = isc_file_mode(filename, &mode);
-	if (result == ISC_R_SUCCESS && mode != 0600) {
+	if (result == ISC_R_SUCCESS && mode != (S_IRUSR | S_IWUSR)) {
 		/* File exists; warn that we are changing its permissions */
 		int level;
 
@@ -660,14 +663,17 @@ dst__privstruct_writefile(const dst_key_t *key, const dst_private_t *priv,
 			      filename, (unsigned int)mode);
 	}
 
-	if ((fp = fopen(filename, "w")) == NULL) {
-		return (DST_R_WRITEERROR);
+	isc_buffer_init(&tmpb, tmpname, sizeof(tmpname));
+	result = dst_key_buildfilename(key, DST_TYPE_TEMPLATE, directory,
+				       &tmpb);
+	if (result != ISC_R_SUCCESS) {
+		return result;
 	}
 
-	access = 0;
-	isc_fsaccess_add(ISC_FSACCESS_OWNER,
-			 ISC_FSACCESS_READ | ISC_FSACCESS_WRITE, &access);
-	(void)isc_fsaccess_set(filename, access);
+	fp = dst_key_open(tmpname, S_IRUSR | S_IWUSR);
+	if (fp == NULL) {
+		return DST_R_WRITEERROR;
+	}
 
 	dst_key_getprivateformat(key, &major, &minor);
 	if (major == 0 && minor == 0) {
@@ -742,8 +748,7 @@ dst__privstruct_writefile(const dst_key_t *key, const dst_private_t *priv,
 		isc_buffer_init(&b, buffer, sizeof(buffer));
 		result = isc_base64_totext(&r, sizeof(buffer), "", &b);
 		if (result != ISC_R_SUCCESS) {
-			fclose(fp);
-			return (DST_R_INVALIDPRIVATEKEY);
+			return dst_key_cleanup(tmpname, fp);
 		}
 		isc_buffer_usedregion(&b, &r);
 
@@ -774,8 +779,7 @@ dst__privstruct_writefile(const dst_key_t *key, const dst_private_t *priv,
 			isc_buffer_init(&b, buffer, sizeof(buffer));
 			result = dns_time32_totext(when, &b);
 			if (result != ISC_R_SUCCESS) {
-				fclose(fp);
-				return (DST_R_INVALIDPRIVATEKEY);
+				return dst_key_cleanup(tmpname, fp);
 			}
 
 			isc_buffer_usedregion(&b, &r);
@@ -787,10 +791,8 @@ dst__privstruct_writefile(const dst_key_t *key, const dst_private_t *priv,
 		}
 	}
 
-	fflush(fp);
-	result = ferror(fp) ? DST_R_WRITEERROR : ISC_R_SUCCESS;
-	fclose(fp);
-	return (result);
+	result = dst_key_close(tmpname, fp, filename);
+	return result;
 }
 
 /*! \file */
