@@ -29,6 +29,7 @@
 #include <dns/cert.h>
 #include <dns/ds.h>
 #include <dns/dsdigest.h>
+#include <dns/dsync.h>
 #include <dns/keyflags.h>
 #include <dns/keyvalues.h>
 #include <dns/rcode.h>
@@ -47,6 +48,10 @@
 
 #define TOTEXTONLY 0x01
 
+/* clang-format off */
+#define SENTINEL { 0, NULL, 0 }
+/* clang-format on */
+
 #define RCODENAMES                                     \
 	/* standard rcodes */                          \
 	{ dns_rcode_noerror, "NOERROR", 0 },           \
@@ -129,6 +134,8 @@
 		{ DNS_DSDIGEST_SHA384, "SHA-384", 0 },                       \
 		{ DNS_DSDIGEST_SHA384, "SHA384", 0 }, { 0, NULL, 0 }
 
+#define DSYNCSCHEMES { DNS_DSYNCSCHEME_NOTIFY, "NOTIFY", 0 }, SENTINEL
+
 struct tbl {
 	unsigned int value;
 	const char *name;
@@ -142,6 +149,7 @@ static struct tbl secalgs[] = { SECALGNAMES };
 static struct tbl secprotos[] = { SECPROTONAMES };
 static struct tbl hashalgs[] = { HASHALGNAMES };
 static struct tbl dsdigests[] = { DSDIGESTNAMES };
+static struct tbl dsyncschemes[] = { DSYNCSCHEMES };
 
 static struct keyflag {
 	const char *name;
@@ -449,6 +457,41 @@ dns_dsdigest_format(dns_dsdigest_t typ, char *cp, unsigned int size) {
 	}
 }
 
+/*
+ * DSYNC Scheme
+ */
+
+isc_result_t
+dns_dsyncscheme_fromtext(dns_dsyncscheme_t *schemep, isc_textregion_t *source) {
+	unsigned int value;
+
+	REQUIRE(schemep != NULL);
+	RETERR(dns_mnemonic_fromtext(&value, source, dsyncschemes, 0xff));
+	*schemep = value;
+	return ISC_R_SUCCESS;
+}
+
+isc_result_t
+dns_dsyncscheme_totext(dns_dsyncscheme_t scheme, isc_buffer_t *target) {
+	return dns_mnemonic_totext(scheme, target, dsyncschemes);
+}
+
+void
+dns_dsyncscheme_format(dns_dsyncscheme_t scheme, char *cp, unsigned int size) {
+	isc_buffer_t b;
+	isc_region_t r;
+	isc_result_t result;
+
+	REQUIRE(cp != NULL && size > 0);
+	isc_buffer_init(&b, cp, size - 1);
+	result = dns_dsyncscheme_totext(scheme, &b);
+	isc_buffer_usedregion(&b, &r);
+	r.base[r.length] = 0;
+	if (result != ISC_R_SUCCESS) {
+		r.base[0] = 0;
+	}
+}
+
 /*
  * This uses lots of hard coded values, but how often do we actually
  * add classes?
