@@ -1,6 +1,8 @@
 /*
  * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
+ * SPDX-License-Identifier: MPL-2.0
+ *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, you can obtain one at https://mozilla.org/MPL/2.0/.
@@ -18,7 +20,7 @@
 
 #define RRTYPE_IPSECKEY_ATTRIBUTES (0)
 
-static inline isc_result_t
+static isc_result_t
 fromtext_ipseckey(ARGS_FROMTEXT) {
 	isc_token_t token;
 	dns_name_t name;
@@ -84,7 +86,7 @@ fromtext_ipseckey(ARGS_FROMTEXT) {
 		}
 		isc_buffer_availableregion(target, &region);
 		if (region.length < 4) {
-			return (ISC_R_NOSPACE);
+			return ISC_R_NOSPACE;
 		}
 		memmove(region.base, &addr, 4);
 		isc_buffer_add(target, 4);
@@ -96,7 +98,7 @@ fromtext_ipseckey(ARGS_FROMTEXT) {
 		}
 		isc_buffer_availableregion(target, &region);
 		if (region.length < 16) {
-			return (ISC_R_NOSPACE);
+			return ISC_R_NOSPACE;
 		}
 		memmove(region.base, addr6, 16);
 		isc_buffer_add(target, 16);
@@ -116,10 +118,10 @@ fromtext_ipseckey(ARGS_FROMTEXT) {
 	/*
 	 * Public key.
 	 */
-	return (isc_base64_tobuffer(lexer, target, -2));
+	return isc_base64_tobuffer(lexer, target, -2);
 }
 
-static inline isc_result_t
+static isc_result_t
 totext_ipseckey(ARGS_TOTEXT) {
 	isc_region_t region;
 	dns_name_t name;
@@ -133,7 +135,7 @@ totext_ipseckey(ARGS_TOTEXT) {
 	dns_name_init(&name, NULL);
 
 	if (rdata->data[1] > 3U) {
-		return (ISC_R_NOTIMPLEMENTED);
+		return ISC_R_NOTIMPLEMENTED;
 	}
 
 	if ((tctx->flags & DNS_STYLEFLAG_MULTILINE) != 0) {
@@ -206,10 +208,10 @@ totext_ipseckey(ARGS_TOTEXT) {
 	if ((tctx->flags & DNS_STYLEFLAG_MULTILINE) != 0) {
 		RETERR(str_totext(" )", target));
 	}
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
-static inline isc_result_t
+static isc_result_t
 fromwire_ipseckey(ARGS_FROMWIRE) {
 	dns_name_t name;
 	isc_region_t region;
@@ -225,30 +227,30 @@ fromwire_ipseckey(ARGS_FROMWIRE) {
 
 	isc_buffer_activeregion(source, &region);
 	if (region.length < 3) {
-		return (ISC_R_UNEXPECTEDEND);
+		return ISC_R_UNEXPECTEDEND;
 	}
 
 	switch (region.base[1]) {
 	case 0:
 		if (region.length < 4) {
-			return (ISC_R_UNEXPECTEDEND);
+			return ISC_R_UNEXPECTEDEND;
 		}
 		isc_buffer_forward(source, region.length);
-		return (mem_tobuffer(target, region.base, region.length));
+		return mem_tobuffer(target, region.base, region.length);
 
 	case 1:
 		if (region.length < 8) {
-			return (ISC_R_UNEXPECTEDEND);
+			return ISC_R_UNEXPECTEDEND;
 		}
 		isc_buffer_forward(source, region.length);
-		return (mem_tobuffer(target, region.base, region.length));
+		return mem_tobuffer(target, region.base, region.length);
 
 	case 2:
 		if (region.length < 20) {
-			return (ISC_R_UNEXPECTEDEND);
+			return ISC_R_UNEXPECTEDEND;
 		}
 		isc_buffer_forward(source, region.length);
-		return (mem_tobuffer(target, region.base, region.length));
+		return mem_tobuffer(target, region.base, region.length);
 
 	case 3:
 		RETERR(mem_tobuffer(target, region.base, 3));
@@ -257,16 +259,16 @@ fromwire_ipseckey(ARGS_FROMWIRE) {
 		isc_buffer_activeregion(source, &region);
 		isc_buffer_forward(source, region.length);
 		if (region.length < 1) {
-			return (ISC_R_UNEXPECTEDEND);
+			return ISC_R_UNEXPECTEDEND;
 		}
-		return (mem_tobuffer(target, region.base, region.length));
+		return mem_tobuffer(target, region.base, region.length);
 
 	default:
-		return (ISC_R_NOTIMPLEMENTED);
+		return ISC_R_NOTIMPLEMENTED;
 	}
 }
 
-static inline isc_result_t
+static isc_result_t
 towire_ipseckey(ARGS_TOWIRE) {
 	isc_region_t region;
 
@@ -276,10 +278,10 @@ towire_ipseckey(ARGS_TOWIRE) {
 	UNUSED(cctx);
 
 	dns_rdata_toregion(rdata, &region);
-	return (mem_tobuffer(target, region.base, region.length));
+	return mem_tobuffer(target, region.base, region.length);
 }
 
-static inline int
+static int
 compare_ipseckey(ARGS_COMPARE) {
 	isc_region_t region1;
 	isc_region_t region2;
@@ -293,10 +295,10 @@ compare_ipseckey(ARGS_COMPARE) {
 	dns_rdata_toregion(rdata1, &region1);
 	dns_rdata_toregion(rdata2, &region2);
 
-	return (isc_region_compare(&region1, &region2));
+	return isc_region_compare(&region1, &region2);
 }
 
-static inline isc_result_t
+static isc_result_t
 fromstruct_ipseckey(ARGS_FROMSTRUCT) {
 	dns_rdata_ipseckey_t *ipseckey = source;
 	isc_region_t region;
@@ -311,7 +313,7 @@ fromstruct_ipseckey(ARGS_FROMSTRUCT) {
 	UNUSED(rdclass);
 
 	if (ipseckey->gateway_type > 3U) {
-		return (ISC_R_NOTIMPLEMENTED);
+		return ISC_R_NOTIMPLEMENTED;
 	}
 
 	RETERR(uint8_tobuffer(ipseckey->precedence, target));
@@ -337,10 +339,10 @@ fromstruct_ipseckey(ARGS_FROMSTRUCT) {
 		break;
 	}
 
-	return (mem_tobuffer(target, ipseckey->key, ipseckey->keylength));
+	return mem_tobuffer(target, ipseckey->key, ipseckey->keylength);
 }
 
-static inline isc_result_t
+static isc_result_t
 tostruct_ipseckey(ARGS_TOSTRUCT) {
 	isc_region_t region;
 	dns_rdata_ipseckey_t *ipseckey = target;
@@ -352,12 +354,10 @@ tostruct_ipseckey(ARGS_TOSTRUCT) {
 	REQUIRE(rdata->length >= 3);
 
 	if (rdata->data[1] > 3U) {
-		return (ISC_R_NOTIMPLEMENTED);
+		return ISC_R_NOTIMPLEMENTED;
 	}
 
-	ipseckey->common.rdclass = rdata->rdclass;
-	ipseckey->common.rdtype = rdata->type;
-	ISC_LINK_INIT(&ipseckey->common, link);
+	DNS_RDATACOMMON_INIT(ipseckey, rdata->type, rdata->rdclass);
 
 	dns_name_init(&name, NULL);
 	dns_rdata_toregion(rdata, &region);
@@ -403,17 +403,17 @@ tostruct_ipseckey(ARGS_TOSTRUCT) {
 				dns_name_free(&ipseckey->gateway,
 					      ipseckey->mctx);
 			}
-			return (ISC_R_NOMEMORY);
+			return ISC_R_NOMEMORY;
 		}
 	} else {
 		ipseckey->key = NULL;
 	}
 
 	ipseckey->mctx = mctx;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
-static inline void
+static void
 freestruct_ipseckey(ARGS_FREESTRUCT) {
 	dns_rdata_ipseckey_t *ipseckey = source;
 
@@ -435,7 +435,7 @@ freestruct_ipseckey(ARGS_FREESTRUCT) {
 	ipseckey->mctx = NULL;
 }
 
-static inline isc_result_t
+static isc_result_t
 additionaldata_ipseckey(ARGS_ADDLDATA) {
 	REQUIRE(rdata->type == dns_rdatatype_ipseckey);
 
@@ -444,20 +444,20 @@ additionaldata_ipseckey(ARGS_ADDLDATA) {
 	UNUSED(add);
 	UNUSED(arg);
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
-static inline isc_result_t
+static isc_result_t
 digest_ipseckey(ARGS_DIGEST) {
 	isc_region_t region;
 
 	REQUIRE(rdata->type == dns_rdatatype_ipseckey);
 
 	dns_rdata_toregion(rdata, &region);
-	return ((digest)(arg, &region));
+	return (digest)(arg, &region);
 }
 
-static inline bool
+static bool
 checkowner_ipseckey(ARGS_CHECKOWNER) {
 	REQUIRE(type == dns_rdatatype_ipseckey);
 
@@ -466,10 +466,10 @@ checkowner_ipseckey(ARGS_CHECKOWNER) {
 	UNUSED(rdclass);
 	UNUSED(wildcard);
 
-	return (true);
+	return true;
 }
 
-static inline bool
+static bool
 checknames_ipseckey(ARGS_CHECKNAMES) {
 	REQUIRE(rdata->type == dns_rdatatype_ipseckey);
 
@@ -477,10 +477,10 @@ checknames_ipseckey(ARGS_CHECKNAMES) {
 	UNUSED(owner);
 	UNUSED(bad);
 
-	return (true);
+	return true;
 }
 
-static inline int
+static int
 casecompare_ipseckey(ARGS_COMPARE) {
 	isc_region_t region1;
 	isc_region_t region2;
@@ -499,7 +499,7 @@ casecompare_ipseckey(ARGS_COMPARE) {
 
 	if (memcmp(region1.base, region2.base, 3) != 0 || region1.base[1] != 3)
 	{
-		return (isc_region_compare(&region1, &region2));
+		return isc_region_compare(&region1, &region2);
 	}
 
 	dns_name_init(&name1, NULL);
@@ -513,13 +513,13 @@ casecompare_ipseckey(ARGS_COMPARE) {
 
 	order = dns_name_rdatacompare(&name1, &name2);
 	if (order != 0) {
-		return (order);
+		return order;
 	}
 
 	isc_region_consume(&region1, name_length(&name1));
 	isc_region_consume(&region2, name_length(&name2));
 
-	return (isc_region_compare(&region1, &region2));
+	return isc_region_compare(&region1, &region2);
 }
 
 #endif /* RDATA_GENERIC_IPSECKEY_45_C */
