@@ -138,9 +138,7 @@ tostruct_isdn(ARGS_TOSTRUCT) {
 	REQUIRE(isdn != NULL);
 	REQUIRE(rdata->length != 0);
 
-	isdn->common.rdclass = rdata->rdclass;
-	isdn->common.rdtype = rdata->type;
-	ISC_LINK_INIT(&isdn->common, link);
+	DNS_RDATACOMMON_INIT(isdn, rdata->type, rdata->rdclass);
 
 	dns_rdata_toregion(rdata, &r);
 
