@@ -1,6 +1,8 @@
 /*
  * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
+ * SPDX-License-Identifier: MPL-2.0
+ *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, you can obtain one at https://mozilla.org/MPL/2.0/.
@@ -14,7 +16,7 @@
 
 #define RRTYPE_SOA_ATTRIBUTES (DNS_RDATATYPEATTR_SINGLETON)
 
-static inline isc_result_t
+static isc_result_t
 fromtext_soa(ARGS_FROMTEXT) {
 	isc_token_t token;
 	dns_name_t name;
@@ -71,13 +73,13 @@ fromtext_soa(ARGS_FROMTEXT) {
 		RETERR(uint32_tobuffer(n, target));
 	}
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static const char *soa_fieldnames[5] = { "serial", "refresh", "retry", "expire",
 					 "minimum" };
 
-static inline isc_result_t
+static isc_result_t
 totext_soa(ARGS_TOTEXT) {
 	isc_region_t dregion;
 	dns_name_t mname;
@@ -148,10 +150,10 @@ totext_soa(ARGS_TOTEXT) {
 		RETERR(str_totext(")", target));
 	}
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
-static inline isc_result_t
+static isc_result_t
 fromwire_soa(ARGS_FROMWIRE) {
 	dns_name_t mname;
 	dns_name_t rname;
@@ -175,20 +177,20 @@ fromwire_soa(ARGS_FROMWIRE) {
 	isc_buffer_availableregion(target, &tregion);
 
 	if (sregion.length < 20) {
-		return (ISC_R_UNEXPECTEDEND);
+		return ISC_R_UNEXPECTEDEND;
 	}
 	if (tregion.length < 20) {
-		return (ISC_R_NOSPACE);
+		return ISC_R_NOSPACE;
 	}
 
 	memmove(tregion.base, sregion.base, 20);
 	isc_buffer_forward(source, 20);
 	isc_buffer_add(target, 20);
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
-static inline isc_result_t
+static isc_result_t
 towire_soa(ARGS_TOWIRE) {
 	isc_region_t sregion;
 	isc_region_t tregion;
@@ -217,15 +219,15 @@ towire_soa(ARGS_TOWIRE) {
 
 	isc_buffer_availableregion(target, &tregion);
 	if (tregion.length < 20) {
-		return (ISC_R_NOSPACE);
+		return ISC_R_NOSPACE;
 	}
 
 	memmove(tregion.base, sregion.base, 20);
 	isc_buffer_add(target, 20);
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
-static inline int
+static int
 compare_soa(ARGS_COMPARE) {
 	isc_region_t region1;
 	isc_region_t region2;
@@ -250,7 +252,7 @@ compare_soa(ARGS_COMPARE) {
 
 	order = dns_name_rdatacompare(&name1, &name2);
 	if (order != 0) {
-		return (order);
+		return order;
 	}
 
 	isc_region_consume(&region1, name_length(&name1));
@@ -264,16 +266,16 @@ compare_soa(ARGS_COMPARE) {
 
 	order = dns_name_rdatacompare(&name1, &name2);
 	if (order != 0) {
-		return (order);
+		return order;
 	}
 
 	isc_region_consume(&region1, name_length(&name1));
 	isc_region_consume(&region2, name_length(&name2));
 
-	return (isc_region_compare(&region1, &region2));
+	return isc_region_compare(&region1, &region2);
 }
 
-static inline isc_result_t
+static isc_result_t
 fromstruct_soa(ARGS_FROMSTRUCT) {
 	dns_rdata_soa_t *soa = source;
 	isc_region_t region;
@@ -294,10 +296,10 @@ fromstruct_soa(ARGS_FROMSTRUCT) {
 	RETERR(uint32_tobuffer(soa->refresh, target));
 	RETERR(uint32_tobuffer(soa->retry, target));
 	RETERR(uint32_tobuffer(soa->expire, target));
-	return (uint32_tobuffer(soa->minimum, target));
+	return uint32_tobuffer(soa->minimum, target);
 }
 
-static inline isc_result_t
+static isc_result_t
 tostruct_soa(ARGS_TOSTRUCT) {
 	isc_region_t region;
 	dns_rdata_soa_t *soa = target;
@@ -307,9 +309,7 @@ tostruct_soa(ARGS_TOSTRUCT) {
 	REQUIRE(soa != NULL);
 	REQUIRE(rdata->length != 0);
 
-	soa->common.rdclass = rdata->rdclass;
-	soa->common.rdtype = rdata->type;
-	ISC_LINK_INIT(&soa->common, link);
+	DNS_RDATACOMMON_INIT(soa, rdata->type, rdata->rdclass);
 
 	dns_rdata_toregion(rdata, &region);
 
@@ -339,10 +339,10 @@ tostruct_soa(ARGS_TOSTRUCT) {
 	soa->minimum = uint32_fromregion(&region);
 
 	soa->mctx = mctx;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
-static inline void
+static void
 freestruct_soa(ARGS_FREESTRUCT) {
 	dns_rdata_soa_t *soa = source;
 
@@ -358,7 +358,7 @@ freestruct_soa(ARGS_FREESTRUCT) {
 	soa->mctx = NULL;
 }
 
-static inline isc_result_t
+static isc_result_t
 additionaldata_soa(ARGS_ADDLDATA) {
 	REQUIRE(rdata->type == dns_rdatatype_soa);
 
@@ -367,10 +367,10 @@ additionaldata_soa(ARGS_ADDLDATA) {
 	UNUSED(add);
 	UNUSED(arg);
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
-static inline isc_result_t
+static isc_result_t
 digest_soa(ARGS_DIGEST) {
 	isc_region_t r;
 	dns_name_t name;
@@ -389,10 +389,10 @@ digest_soa(ARGS_DIGEST) {
 	RETERR(dns_name_digest(&name, digest, arg));
 	isc_region_consume(&r, name_length(&name));
 
-	return ((digest)(arg, &r));
+	return (digest)(arg, &r);
 }
 
-static inline bool
+static bool
 checkowner_soa(ARGS_CHECKOWNER) {
 	REQUIRE(type == dns_rdatatype_soa);
 
@@ -401,10 +401,10 @@ checkowner_soa(ARGS_CHECKOWNER) {
 	UNUSED(rdclass);
 	UNUSED(wildcard);
 
-	return (true);
+	return true;
 }
 
-static inline bool
+static bool
 checknames_soa(ARGS_CHECKNAMES) {
 	isc_region_t region;
 	dns_name_t name;
@@ -420,7 +420,7 @@ checknames_soa(ARGS_CHECKNAMES) {
 		if (bad != NULL) {
 			dns_name_clone(&name, bad);
 		}
-		return (false);
+		return false;
 	}
 	isc_region_consume(&region, name_length(&name));
 	dns_name_fromregion(&name, &region);
@@ -428,14 +428,14 @@ checknames_soa(ARGS_CHECKNAMES) {
 		if (bad != NULL) {
 			dns_name_clone(&name, bad);
 		}
-		return (false);
+		return false;
 	}
-	return (true);
+	return true;
 }
 
-static inline int
+static int
 casecompare_soa(ARGS_COMPARE) {
-	return (compare_soa(rdata1, rdata2));
+	return compare_soa(rdata1, rdata2);
 }
 
 #endif /* RDATA_GENERIC_SOA_6_C */
