@@ -182,20 +182,20 @@ const char *
 dns_rpz_type2str(dns_rpz_type_t type) {
 	switch (type) {
 	case DNS_RPZ_TYPE_CLIENT_IP:
-		return ("CLIENT-IP");
+		return "CLIENT-IP";
 	case DNS_RPZ_TYPE_QNAME:
-		return ("QNAME");
+		return "QNAME";
 	case DNS_RPZ_TYPE_IP:
-		return ("IP");
+		return "IP";
 	case DNS_RPZ_TYPE_NSIP:
-		return ("NSIP");
+		return "NSIP";
 	case DNS_RPZ_TYPE_NSDNAME:
-		return ("NSDNAME");
+		return "NSDNAME";
 	case DNS_RPZ_TYPE_BAD:
 		break;
 	}
 	FATAL_ERROR("impossible rpz type %d", type);
-	return ("impossible");
+	return "impossible";
 }
 
 dns_rpz_policy_t
@@ -217,14 +217,14 @@ dns_rpz_str2policy(const char *str) {
 	unsigned int n;
 
 	if (str == NULL) {
-		return (DNS_RPZ_POLICY_ERROR);
+		return DNS_RPZ_POLICY_ERROR;
 	}
 	for (n = 0; n < sizeof(tbl) / sizeof(tbl[0]); ++n) {
 		if (!strcasecmp(tbl[n].str, str)) {
-			return (tbl[n].policy);
+			return tbl[n].policy;
 		}
 	}
-	return (DNS_RPZ_POLICY_ERROR);
+	return DNS_RPZ_POLICY_ERROR;
 }
 
 const char *
@@ -266,7 +266,7 @@ dns_rpz_policy2str(dns_rpz_policy_t policy) {
 	default:
 		UNREACHABLE();
 	}
-	return (str);
+	return str;
 }
 
 /*
@@ -302,7 +302,7 @@ zbit_to_num(dns_rpz_zbits_t zbit) {
 	if ((zbit & 2) != 0) {
 		++rpz_num;
 	}
-	return (rpz_num);
+	return rpz_num;
 }
 
 /*
@@ -646,7 +646,7 @@ new_node(dns_rpz_zones_t *rpzs, const dns_rpz_cidr_key_t *ip,
 		node->ip.w[i++] = 0;
 	}
 
-	return (node);
+	return node;
 }
 
 static void
@@ -693,7 +693,7 @@ ip2name(const dns_rpz_cidr_key_t *tgt_ip, dns_rpz_prefix_t tgt_prefix,
 			       (tgt_ip->w[3] >> 16) & 0xffU,
 			       (tgt_ip->w[3] >> 24) & 0xffU);
 		if (len < 0 || (size_t)len >= sizeof(str)) {
-			return (ISC_R_FAILURE);
+			return ISC_R_FAILURE;
 		}
 	} else {
 		int w[DNS_RPZ_CIDR_WORDS * 2];
@@ -701,7 +701,7 @@ ip2name(const dns_rpz_cidr_key_t *tgt_ip, dns_rpz_prefix_t tgt_prefix,
 
 		len = snprintf(str, sizeof(str), "%d", tgt_prefix);
 		if (len < 0 || (size_t)len >= sizeof(str)) {
-			return (ISC_R_FAILURE);
+			return ISC_R_FAILURE;
 		}
 
 		for (int n = 0; n < DNS_RPZ_CIDR_WORDS; n++) {
@@ -747,7 +747,7 @@ ip2name(const dns_rpz_cidr_key_t *tgt_ip, dns_rpz_prefix_t tgt_prefix,
 					     ".%x", w[n]);
 			}
 			if (i < 0 || (size_t)i >= (size_t)(sizeof(str) - len)) {
-				return (ISC_R_FAILURE);
+				return ISC_R_FAILURE;
 			}
 			len += i;
 		}
@@ -756,7 +756,7 @@ ip2name(const dns_rpz_cidr_key_t *tgt_ip, dns_rpz_prefix_t tgt_prefix,
 	isc_buffer_init(&buffer, str, sizeof(str));
 	isc_buffer_add(&buffer, len);
 	result = dns_name_fromtext(ip_name, &buffer, base_name, 0, NULL);
-	return (result);
+	return result;
 }
 
 /*
@@ -766,26 +766,26 @@ static dns_rpz_type_t
 type_from_name(const dns_rpz_zones_t *rpzs, dns_rpz_zone_t *rpz,
 	       const dns_name_t *name) {
 	if (dns_name_issubdomain(name, &rpz->ip)) {
-		return (DNS_RPZ_TYPE_IP);
+		return DNS_RPZ_TYPE_IP;
 	}
 
 	if (dns_name_issubdomain(name, &rpz->client_ip)) {
-		return (DNS_RPZ_TYPE_CLIENT_IP);
+		return DNS_RPZ_TYPE_CLIENT_IP;
 	}
 
 	if ((rpzs->p.nsip_on & DNS_RPZ_ZBIT(rpz->num)) != 0 &&
 	    dns_name_issubdomain(name, &rpz->nsip))
 	{
-		return (DNS_RPZ_TYPE_NSIP);
+		return DNS_RPZ_TYPE_NSIP;
 	}
 
 	if ((rpzs->p.nsdname_on & DNS_RPZ_ZBIT(rpz->num)) != 0 &&
 	    dns_name_issubdomain(name, &rpz->nsdname))
 	{
-		return (DNS_RPZ_TYPE_NSDNAME);
+		return DNS_RPZ_TYPE_NSDNAME;
 	}
 
-	return (DNS_RPZ_TYPE_QNAME);
+	return DNS_RPZ_TYPE_QNAME;
 }
 
 /*
@@ -802,7 +802,7 @@ name2ipkey(int log_level, dns_rpz_zone_t *rpz, dns_rpz_type_t rpz_type,
 	dns_fixedname_t ip_name2f;
 	dns_name_t ip_name;
 	const char *prefix_str = NULL, *cp = NULL, *end = NULL;
-	char *cp2;
+	char *prefix_end, *cp2;
 	int ip_labels;
 	dns_rpz_prefix_t prefix;
 	unsigned long prefix_num, l;
@@ -822,7 +822,7 @@ name2ipkey(int log_level, dns_rpz_zone_t *rpz, dns_rpz_type_t rpz_type,
 	}
 	if (ip_labels < 2) {
 		badname(log_level, src_name, "; too short", "");
-		return (ISC_R_FAILURE);
+		return ISC_R_FAILURE;
 	}
 	dns_name_init(&ip_name, ip_name_offsets);
 	dns_name_getlabelsequence(src_name, 0, ip_labels, &ip_name);
@@ -838,17 +838,14 @@ name2ipkey(int log_level, dns_rpz_zone_t *rpz, dns_rpz_type_t rpz_type,
 	if (*cp2 != '.') {
 		badname(log_level, src_name, "; invalid leading prefix length",
 			"");
-		return (ISC_R_FAILURE);
+		return ISC_R_FAILURE;
 	}
-	/*
-	 * Patch in trailing nul character to print just the length
-	 * label (for various cases below).
-	 */
-	*cp2 = '\0';
+	prefix_end = cp2;
 	if (prefix_num < 1U || prefix_num > 128U) {
+		*prefix_end = '\0';
 		badname(log_level, src_name, "; invalid prefix length of ",
 			prefix_str);
-		return (ISC_R_FAILURE);
+		return ISC_R_FAILURE;
 	}
 	cp = cp2 + 1;
 
@@ -858,9 +855,10 @@ name2ipkey(int log_level, dns_rpz_zone_t *rpz, dns_rpz_type_t rpz_type,
 		 * from the form "prefix.z.y.x.w"
 		 */
 		if (prefix_num > 32U) {
+			*prefix_end = '\0';
 			badname(log_level, src_name,
 				"; invalid IPv4 prefix length of ", prefix_str);
-			return (ISC_R_FAILURE);
+			return ISC_R_FAILURE;
 		}
 		prefix_num += 96;
 		*tgt_prefix = (dns_rpz_prefix_t)prefix_num;
@@ -876,7 +874,7 @@ name2ipkey(int log_level, dns_rpz_zone_t *rpz, dns_rpz_type_t rpz_type,
 				}
 				badname(log_level, src_name,
 					"; invalid IPv4 octet ", cp);
-				return (ISC_R_FAILURE);
+				return ISC_R_FAILURE;
 			}
 			tgt_ip->w[3] |= l << i;
 			cp = cp2 + 1;
@@ -909,7 +907,7 @@ name2ipkey(int log_level, dns_rpz_zone_t *rpz, dns_rpz_type_t rpz_type,
 					}
 					badname(log_level, src_name,
 						"; invalid IPv6 word ", cp);
-					return (ISC_R_FAILURE);
+					return ISC_R_FAILURE;
 				}
 				if ((i & 1) == 0) {
 					tgt_ip->w[3 - i / 2] = l;
@@ -923,7 +921,7 @@ name2ipkey(int log_level, dns_rpz_zone_t *rpz, dns_rpz_type_t rpz_type,
 	}
 	if (cp != end) {
 		badname(log_level, src_name, "", "");
-		return (ISC_R_FAILURE);
+		return ISC_R_FAILURE;
 	}
 
 	/*
@@ -936,9 +934,10 @@ name2ipkey(int log_level, dns_rpz_zone_t *rpz, dns_rpz_type_t rpz_type,
 		i = prefix % DNS_RPZ_CIDR_WORD_BITS;
 		aword = tgt_ip->w[prefix / DNS_RPZ_CIDR_WORD_BITS];
 		if ((aword & ~DNS_RPZ_WORD_MASK(i)) != 0) {
+			*prefix_end = '\0';
 			badname(log_level, src_name,
 				"; too small prefix length of ", prefix_str);
-			return (ISC_R_FAILURE);
+			return ISC_R_FAILURE;
 		}
 		prefix -= i;
 		prefix += DNS_RPZ_CIDR_WORD_BITS;
@@ -970,7 +969,7 @@ name2ipkey(int log_level, dns_rpz_zone_t *rpz, dns_rpz_type_t rpz_type,
 		}
 	}
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 /*
@@ -1050,7 +1049,7 @@ clz(dns_rpz_cidr_word_t w) {
 		--bit;
 	}
 
-	return (bit);
+	return bit;
 }
 #endif /* ifndef HAVE_BUILTIN_CLZ */
 
@@ -1081,7 +1080,7 @@ diff_keys(const dns_rpz_cidr_key_t *key1, dns_rpz_prefix_t prefix1,
 			break;
 		}
 	}
-	return (ISC_MIN(bit, maxbit));
+	return ISC_MIN(bit, maxbit);
 }
 
 /*
@@ -1100,7 +1099,7 @@ trim_zbits(dns_rpz_zbits_t zbits, dns_rpz_zbits_t found) {
 	x &= (~x + 1);
 	x = (x << 1) - 1;
 	zbits &= x;
-	return (zbits);
+	return zbits;
 }
 
 /*
@@ -1136,11 +1135,11 @@ search(dns_rpz_zones_t *rpzs, const dns_rpz_cidr_key_t *tgt_ip,
 			 * or add the target as a child of the current parent.
 			 */
 			if (!create) {
-				return (find_result);
+				return find_result;
 			}
 			child = new_node(rpzs, tgt_ip, tgt_prefix, NULL);
 			if (child == NULL) {
-				return (ISC_R_NOMEMORY);
+				return ISC_R_NOMEMORY;
 			}
 			if (parent == NULL) {
 				rpzs->cidr = child;
@@ -1153,7 +1152,7 @@ search(dns_rpz_zones_t *rpzs, const dns_rpz_cidr_key_t *tgt_ip,
 			child->set.nsip |= tgt_set->nsip;
 			set_sum_pair(child);
 			*found = child;
-			return (ISC_R_SUCCESS);
+			return ISC_R_SUCCESS;
 		}
 
 		if ((cur->sum.client_ip & set.client_ip) == 0 &&
@@ -1169,7 +1168,7 @@ search(dns_rpz_zones_t *rpzs, const dns_rpz_cidr_key_t *tgt_ip,
 			 * a node and mark/put this node in the correct tree.
 			 */
 			if (!create) {
-				return (find_result);
+				return find_result;
 			}
 		}
 
@@ -1209,7 +1208,7 @@ search(dns_rpz_zones_t *rpzs, const dns_rpz_cidr_key_t *tgt_ip,
 					*found = cur;
 					find_result = ISC_R_SUCCESS;
 				}
-				return (find_result);
+				return find_result;
 			}
 
 			/*
@@ -1218,12 +1217,12 @@ search(dns_rpz_zones_t *rpzs, const dns_rpz_cidr_key_t *tgt_ip,
 			 * Add the target as the current node's parent.
 			 */
 			if (!create) {
-				return (find_result);
+				return find_result;
 			}
 
 			new_parent = new_node(rpzs, tgt_ip, tgt_prefix, cur);
 			if (new_parent == NULL) {
-				return (ISC_R_NOMEMORY);
+				return ISC_R_NOMEMORY;
 			}
 			new_parent->parent = parent;
 			if (parent == NULL) {
@@ -1237,7 +1236,7 @@ search(dns_rpz_zones_t *rpzs, const dns_rpz_cidr_key_t *tgt_ip,
 			new_parent->set = *tgt_set;
 			set_sum_pair(new_parent);
 			*found = new_parent;
-			return (ISC_R_SUCCESS);
+			return ISC_R_SUCCESS;
 		}
 
 		if (dbit == cur->prefix) {
@@ -1271,17 +1270,17 @@ search(dns_rpz_zones_t *rpzs, const dns_rpz_cidr_key_t *tgt_ip,
 		 * add the target as a sibling of the current node
 		 */
 		if (!create) {
-			return (find_result);
+			return find_result;
 		}
 
 		sibling = new_node(rpzs, tgt_ip, tgt_prefix, NULL);
 		if (sibling == NULL) {
-			return (ISC_R_NOMEMORY);
+			return ISC_R_NOMEMORY;
 		}
 		new_parent = new_node(rpzs, tgt_ip, dbit, cur);
 		if (new_parent == NULL) {
 			isc_mem_put(rpzs->mctx, sibling, sizeof(*sibling));
-			return (ISC_R_NOMEMORY);
+			return ISC_R_NOMEMORY;
 		}
 		new_parent->parent = parent;
 		if (parent == NULL) {
@@ -1297,7 +1296,7 @@ search(dns_rpz_zones_t *rpzs, const dns_rpz_cidr_key_t *tgt_ip,
 		sibling->set = *tgt_set;
 		set_sum_pair(sibling);
 		*found = sibling;
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
 }
 
@@ -1319,7 +1318,7 @@ add_cidr(dns_rpz_zone_t *rpz, dns_rpz_type_t rpz_type,
 	 * Log complaints about bad owner names but let the zone load.
 	 */
 	if (result != ISC_R_SUCCESS) {
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
 
 	result = search(rpz->rpzs, &tgt_ip, tgt_prefix, &set, true, &found);
@@ -1331,7 +1330,7 @@ add_cidr(dns_rpz_zone_t *rpz, dns_rpz_type_t rpz_type,
 		 * because diff_apply() likes to add nodes before deleting.
 		 */
 		if (result == ISC_R_EXISTS) {
-			return (ISC_R_SUCCESS);
+			return ISC_R_SUCCESS;
 		}
 
 		/*
@@ -1342,11 +1341,11 @@ add_cidr(dns_rpz_zone_t *rpz, dns_rpz_type_t rpz_type,
 			      DNS_LOGMODULE_RBTDB, DNS_RPZ_ERROR_LEVEL,
 			      "rpz add_cidr(%s) failed: %s", namebuf,
 			      isc_result_totext(result));
-		return (result);
+		return result;
 	}
 
 	adj_trigger_cnt(rpz, rpz_type, &tgt_ip, tgt_prefix, true);
-	return (result);
+	return result;
 }
 
 static isc_result_t
@@ -1366,11 +1365,11 @@ add_nm(dns_rpz_zones_t *rpzs, dns_name_t *trig_name,
 			nm_data = isc_mem_get(rpzs->mctx, sizeof(*nm_data));
 			*nm_data = *new_data;
 			nmnode->data = nm_data;
-			return (ISC_R_SUCCESS);
+			return ISC_R_SUCCESS;
 		}
 		break;
 	default:
-		return (result);
+		return result;
 	}
 
 	/*
@@ -1381,14 +1380,14 @@ add_nm(dns_rpz_zones_t *rpzs, dns_name_t *trig_name,
 	    (nm_data->wild.qname & new_data->wild.qname) != 0 ||
 	    (nm_data->wild.ns & new_data->wild.ns) != 0)
 	{
-		return (ISC_R_EXISTS);
+		return ISC_R_EXISTS;
 	}
 
 	nm_data->set.qname |= new_data->set.qname;
 	nm_data->set.ns |= new_data->set.ns;
 	nm_data->wild.qname |= new_data->wild.qname;
 	nm_data->wild.ns |= new_data->wild.ns;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -1414,12 +1413,12 @@ add_name(dns_rpz_zone_t *rpz, dns_rpz_type_t rpz_type,
 	 * because diff_apply() likes to add nodes before deleting.
 	 */
 	if (result == ISC_R_EXISTS) {
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
 	if (result == ISC_R_SUCCESS) {
 		adj_trigger_cnt(rpz, rpz_type, NULL, 0, true);
 	}
-	return (result);
+	return result;
 }
 
 /*
@@ -1482,7 +1481,7 @@ dns_rpz_new_zones(isc_mem_t *mctx, isc_taskmgr_t *taskmgr,
 	isc_mem_attach(mctx, &rpzs->mctx);
 
 	*rpzsp = rpzs;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 
 cleanup_task:
 	dns_rbt_destroy(&rpzs->rbt);
@@ -1494,7 +1493,7 @@ cleanup_rbt:
 	isc_rwlock_destroy(&rpzs->search_lock);
 	isc_mem_put(mctx, rpzs, sizeof(*rpzs));
 
-	return (result);
+	return result;
 }
 
 isc_result_t
@@ -1506,12 +1505,12 @@ dns_rpz_new_zone(dns_rpz_zones_t *rpzs, dns_rpz_zone_t **rpzp) {
 	REQUIRE(rpzp != NULL && *rpzp == NULL);
 
 	if (rpzs->p.num_zones >= DNS_RPZ_MAX_ZONES) {
-		return (ISC_R_NOSPACE);
+		return ISC_R_NOSPACE;
 	}
 
 	result = dns__rpz_shuttingdown(rpzs);
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		return result;
 	}
 
 	rpz = isc_mem_get(rpzs->mctx, sizeof(*rpz));
@@ -1555,12 +1554,12 @@ dns_rpz_new_zone(dns_rpz_zones_t *rpzs, dns_rpz_zone_t **rpzp) {
 
 	*rpzp = rpz;
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 
 cleanup_timer:
 	isc_mem_put(rpzs->mctx, rpz, sizeof(*rpz));
 
-	return (result);
+	return result;
 }
 
 isc_result_t
@@ -1646,7 +1645,7 @@ dns_rpz_dbupdate_callback(dns_db_t *db, void *fn_arg) {
 unlock:
 	UNLOCK(&rpz->rpzs->maint_lock);
 
-	return (result);
+	return result;
 }
 
 static void
@@ -1725,7 +1724,7 @@ update_nodes(dns_rpz_zone_t *rpz, isc_ht_t *newnodes) {
 			      DNS_LOGMODULE_MASTER, ISC_LOG_ERROR,
 			      "rpz: %s: failed to create DB iterator - %s",
 			      domain, isc_result_totext(result));
-		return (result);
+		return result;
 	}
 
 	result = dns_dbiterator_first(updbit);
@@ -1846,7 +1845,7 @@ update_nodes(dns_rpz_zone_t *rpz, isc_ht_t *newnodes) {
 cleanup:
 	dns_dbiterator_destroy(&updbit);
 
-	return (result);
+	return result;
 }
 
 static isc_result_t
@@ -1888,7 +1887,7 @@ cleanup_nodes(dns_rpz_zone_t *rpz) {
 
 	isc_ht_iter_destroy(&iter);
 
-	return (result);
+	return result;
 }
 
 static isc_result_t
@@ -1900,10 +1899,10 @@ dns__rpz_shuttingdown(dns_rpz_zones_t *rpzs) {
 	UNLOCK(&rpzs->maint_lock);
 
 	if (shuttingdown) {
-		return (ISC_R_SHUTTINGDOWN);
+		return ISC_R_SHUTTINGDOWN;
 	}
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static void
@@ -2194,7 +2193,7 @@ rpz_add(dns_rpz_zone_t *rpz, const dns_name_t *src_name) {
 	}
 	RWUNLOCK(&rpzs->search_lock, isc_rwlocktype_write);
 
-	return (result);
+	return result;
 }
 
 /*
@@ -2486,11 +2485,11 @@ dns_rpz_find_ip(dns_rpz_zones_t *rpzs, dns_rpz_type_t rpz_type,
 			break;
 		}
 	} else {
-		return (DNS_RPZ_INVALID_NUM);
+		return DNS_RPZ_INVALID_NUM;
 	}
 
 	if (zbits == 0) {
-		return (DNS_RPZ_INVALID_NUM);
+		return DNS_RPZ_INVALID_NUM;
 	}
 	make_addr_set(&tgt_set, zbits, rpz_type);
 
@@ -2501,7 +2500,7 @@ dns_rpz_find_ip(dns_rpz_zones_t *rpzs, dns_rpz_type_t rpz_type,
 		 * There are no eligible zones for this IP address.
 		 */
 		RWUNLOCK(&rpzs->search_lock, isc_rwlocktype_read);
-		return (DNS_RPZ_INVALID_NUM);
+		return DNS_RPZ_INVALID_NUM;
 	}
 
 	/*
@@ -2532,9 +2531,9 @@ dns_rpz_find_ip(dns_rpz_zones_t *rpzs, dns_rpz_type_t rpz_type,
 			      DNS_LOGMODULE_RBTDB, DNS_RPZ_ERROR_LEVEL,
 			      "rpz ip2name() failed: %s",
 			      isc_result_totext(result));
-		return (DNS_RPZ_INVALID_NUM);
+		return DNS_RPZ_INVALID_NUM;
 	}
-	return (rpz_num);
+	return rpz_num;
 }
 
 /*
@@ -2553,7 +2552,7 @@ dns_rpz_find_name(dns_rpz_zones_t *rpzs, dns_rpz_type_t rpz_type,
 	int i;
 
 	if (zbits == 0) {
-		return (0);
+		return 0;
 	}
 
 	found_zbits = 0;
@@ -2653,7 +2652,7 @@ dns_rpz_find_name(dns_rpz_zones_t *rpzs, dns_rpz_type_t rpz_type,
 
 	dns_rbtnodechain_invalidate(&chain);
 
-	return (zbits & found_zbits);
+	return zbits & found_zbits;
 }
 
 /*
@@ -2677,7 +2676,7 @@ dns_rpz_decode_cname(dns_rpz_zone_t *rpz, dns_rdataset_t *rdataset,
 	 * CNAME . means NXDOMAIN
 	 */
 	if (dns_name_equal(&cname.cname, dns_rootname)) {
-		return (DNS_RPZ_POLICY_NXDOMAIN);
+		return DNS_RPZ_POLICY_NXDOMAIN;
 	}
 
 	if (dns_name_iswildcard(&cname.cname)) {
@@ -2685,7 +2684,7 @@ dns_rpz_decode_cname(dns_rpz_zone_t *rpz, dns_rdataset_t *rdataset,
 		 * CNAME *. means NODATA
 		 */
 		if (dns_name_countlabels(&cname.cname) == 2) {
-			return (DNS_RPZ_POLICY_NODATA);
+			return DNS_RPZ_POLICY_NODATA;
 		}
 
 		/*
@@ -2695,7 +2694,7 @@ dns_rpz_decode_cname(dns_rpz_zone_t *rpz, dns_rdataset_t *rdataset,
 		 *	evil.com    CNAME   evil.com.garden.net
 		 */
 		if (dns_name_countlabels(&cname.cname) > 2) {
-			return (DNS_RPZ_POLICY_WILDCNAME);
+			return DNS_RPZ_POLICY_WILDCNAME;
 		}
 	}
 
@@ -2703,32 +2702,32 @@ dns_rpz_decode_cname(dns_rpz_zone_t *rpz, dns_rdataset_t *rdataset,
 	 * CNAME rpz-tcp-only. means "send truncated UDP responses."
 	 */
 	if (dns_name_equal(&cname.cname, &rpz->tcp_only)) {
-		return (DNS_RPZ_POLICY_TCP_ONLY);
+		return DNS_RPZ_POLICY_TCP_ONLY;
 	}
 
 	/*
 	 * CNAME rpz-drop. means "do not respond."
 	 */
 	if (dns_name_equal(&cname.cname, &rpz->drop)) {
-		return (DNS_RPZ_POLICY_DROP);
+		return DNS_RPZ_POLICY_DROP;
 	}
 
 	/*
 	 * CNAME rpz-passthru. means "do not rewrite."
 	 */
 	if (dns_name_equal(&cname.cname, &rpz->passthru)) {
-		return (DNS_RPZ_POLICY_PASSTHRU);
+		return DNS_RPZ_POLICY_PASSTHRU;
 	}
 
 	/*
 	 * 128.1.0.127.rpz-ip CNAME  128.1.0.0.127. is obsolete PASSTHRU
 	 */
 	if (selfname != NULL && dns_name_equal(&cname.cname, selfname)) {
-		return (DNS_RPZ_POLICY_PASSTHRU);
+		return DNS_RPZ_POLICY_PASSTHRU;
 	}
 
 	/*
 	 * Any other rdata gives a response consisting of the rdata.
 	 */
-	return (DNS_RPZ_POLICY_RECORD);
+	return DNS_RPZ_POLICY_RECORD;
 }
