@@ -29,11 +29,6 @@
 #include <isc/tm.h>
 #include <isc/util.h>
 
-#define NS_PER_S  1000000000 /*%< Nanoseconds per second. */
-#define NS_PER_US 1000	     /*%< Nanoseconds per microsecond. */
-#define NS_PER_MS 1000000    /*%< Nanoseconds per millisecond. */
-#define MS_PER_S  1000	     /*%< Milliseonds per second. */
-
 #if defined(CLOCK_REALTIME)
 #define CLOCKSOURCE_HIRES CLOCK_REALTIME
 #endif /* #if defined(CLOCK_REALTIME) */
@@ -63,7 +58,7 @@ void
 isc_interval_set(isc_interval_t *i, unsigned int seconds,
 		 unsigned int nanoseconds) {
 	REQUIRE(i != NULL);
-	REQUIRE(nanoseconds < NS_PER_S);
+	REQUIRE(nanoseconds < NS_PER_SEC);
 
 	i->seconds = seconds;
 	i->nanoseconds = nanoseconds;
@@ -72,21 +67,21 @@ isc_interval_set(isc_interval_t *i, unsigned int seconds,
 bool
 isc_interval_iszero(const isc_interval_t *i) {
 	REQUIRE(i != NULL);
-	INSIST(i->nanoseconds < NS_PER_S);
+	INSIST(i->nanoseconds < NS_PER_SEC);
 
 	if (i->seconds == 0 && i->nanoseconds == 0) {
-		return (true);
+		return true;
 	}
 
-	return (false);
+	return false;
 }
 
 unsigned int
 isc_interval_ms(const isc_interval_t *i) {
 	REQUIRE(i != NULL);
-	INSIST(i->nanoseconds < NS_PER_S);
+	INSIST(i->nanoseconds < NS_PER_SEC);
 
-	return ((i->seconds * MS_PER_S) + (i->nanoseconds / NS_PER_MS));
+	return (i->seconds * MS_PER_SEC) + (i->nanoseconds / NS_PER_MS);
 }
 
 /***
@@ -101,7 +96,7 @@ const isc_time_t *const isc_time_epoch = &epoch;
 void
 isc_time_set(isc_time_t *t, unsigned int seconds, unsigned int nanoseconds) {
 	REQUIRE(t != NULL);
-	REQUIRE(nanoseconds < NS_PER_S);
+	REQUIRE(nanoseconds < NS_PER_SEC);
 
 	t->seconds = seconds;
 	t->nanoseconds = nanoseconds;
@@ -118,13 +113,13 @@ isc_time_settoepoch(isc_time_t *t) {
 bool
 isc_time_isepoch(const isc_time_t *t) {
 	REQUIRE(t != NULL);
-	INSIST(t->nanoseconds < NS_PER_S);
+	INSIST(t->nanoseconds < NS_PER_SEC);
 
 	if (t->seconds == 0 && t->nanoseconds == 0) {
-		return (true);
+		return true;
 	}
 
-	return (false);
+	return false;
 }
 
 static isc_result_t
@@ -135,11 +130,11 @@ time_now(isc_time_t *t, clockid_t clock) {
 
 	if (clock_gettime(clock, &ts) == -1) {
 		UNEXPECTED_SYSERROR(errno, "clock_gettime()");
-		return (ISC_R_UNEXPECTED);
+		return ISC_R_UNEXPECTED;
 	}
 
-	if (ts.tv_sec < 0 || ts.tv_nsec < 0 || ts.tv_nsec >= NS_PER_S) {
-		return (ISC_R_UNEXPECTED);
+	if (ts.tv_sec < 0 || ts.tv_nsec < 0 || ts.tv_nsec >= (long)NS_PER_SEC) {
+		return ISC_R_UNEXPECTED;
 	}
 
 	/*
@@ -148,13 +143,13 @@ time_now(isc_time_t *t, clockid_t clock) {
 	if (sizeof(ts.tv_sec) > sizeof(t->seconds) &&
 	    ((ts.tv_sec | (unsigned int)-1) ^ (unsigned int)-1) != 0U)
 	{
-		return (ISC_R_RANGE);
+		return ISC_R_RANGE;
 	}
 
 	t->seconds = ts.tv_sec;
 	t->nanoseconds = ts.tv_nsec;
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 isc_result_t
@@ -173,15 +168,15 @@ isc_time_nowplusinterval(isc_time_t *t, const isc_interval_t *i) {
 
 	REQUIRE(t != NULL);
 	REQUIRE(i != NULL);
-	INSIST(i->nanoseconds < NS_PER_S);
+	INSIST(i->nanoseconds < NS_PER_SEC);
 
 	if (clock_gettime(CLOCKSOURCE, &ts) == -1) {
 		UNEXPECTED_SYSERROR(errno, "clock_gettime()");
-		return (ISC_R_UNEXPECTED);
+		return ISC_R_UNEXPECTED;
 	}
 
-	if (ts.tv_sec < 0 || ts.tv_nsec < 0 || ts.tv_nsec >= NS_PER_S) {
-		return (ISC_R_UNEXPECTED);
+	if (ts.tv_sec < 0 || ts.tv_nsec < 0 || ts.tv_nsec >= (long)NS_PER_SEC) {
+		return ISC_R_UNEXPECTED;
 	}
 
 	/*
@@ -193,83 +188,83 @@ isc_time_nowplusinterval(isc_time_t *t, const isc_interval_t *i) {
 	if ((ts.tv_sec > INT_MAX || i->seconds > INT_MAX) &&
 	    ((long long)ts.tv_sec + i->seconds > UINT_MAX))
 	{
-		return (ISC_R_RANGE);
+		return ISC_R_RANGE;
 	}
 
 	t->seconds = ts.tv_sec + i->seconds;
 	t->nanoseconds = ts.tv_nsec + i->nanoseconds;
-	if (t->nanoseconds >= NS_PER_S) {
+	if (t->nanoseconds >= NS_PER_SEC) {
 		t->seconds++;
-		t->nanoseconds -= NS_PER_S;
+		t->nanoseconds -= NS_PER_SEC;
 	}
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 int
 isc_time_compare(const isc_time_t *t1, const isc_time_t *t2) {
 	REQUIRE(t1 != NULL && t2 != NULL);
-	INSIST(t1->nanoseconds < NS_PER_S && t2->nanoseconds < NS_PER_S);
+	INSIST(t1->nanoseconds < NS_PER_SEC && t2->nanoseconds < NS_PER_SEC);
 
 	if (t1->seconds < t2->seconds) {
-		return (-1);
+		return -1;
 	}
 	if (t1->seconds > t2->seconds) {
-		return (1);
+		return 1;
 	}
 	if (t1->nanoseconds < t2->nanoseconds) {
-		return (-1);
+		return -1;
 	}
 	if (t1->nanoseconds > t2->nanoseconds) {
-		return (1);
+		return 1;
 	}
-	return (0);
+	return 0;
 }
 
 isc_result_t
 isc_time_add(const isc_time_t *t, const isc_interval_t *i, isc_time_t *result) {
 	REQUIRE(t != NULL && i != NULL && result != NULL);
-	REQUIRE(t->nanoseconds < NS_PER_S && i->nanoseconds < NS_PER_S);
+	REQUIRE(t->nanoseconds < NS_PER_SEC && i->nanoseconds < NS_PER_SEC);
 
 	/* Seconds */
 #if HAVE_BUILTIN_OVERFLOW
 	if (__builtin_uadd_overflow(t->seconds, i->seconds, &result->seconds)) {
-		return (ISC_R_RANGE);
+		return ISC_R_RANGE;
 	}
 #else
 	if (t->seconds > UINT_MAX - i->seconds) {
-		return (ISC_R_RANGE);
+		return ISC_R_RANGE;
 	}
 	result->seconds = t->seconds + i->seconds;
 #endif
 
 	/* Nanoseconds */
 	result->nanoseconds = t->nanoseconds + i->nanoseconds;
-	if (result->nanoseconds >= NS_PER_S) {
+	if (result->nanoseconds >= NS_PER_SEC) {
 		if (result->seconds == UINT_MAX) {
-			return (ISC_R_RANGE);
+			return ISC_R_RANGE;
 		}
-		result->nanoseconds -= NS_PER_S;
+		result->nanoseconds -= NS_PER_SEC;
 		result->seconds++;
 	}
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 isc_result_t
 isc_time_subtract(const isc_time_t *t, const isc_interval_t *i,
 		  isc_time_t *result) {
 	REQUIRE(t != NULL && i != NULL && result != NULL);
-	REQUIRE(t->nanoseconds < NS_PER_S && i->nanoseconds < NS_PER_S);
+	REQUIRE(t->nanoseconds < NS_PER_SEC && i->nanoseconds < NS_PER_SEC);
 
 	/* Seconds */
 #if HAVE_BUILTIN_OVERFLOW
 	if (__builtin_usub_overflow(t->seconds, i->seconds, &result->seconds)) {
-		return (ISC_R_RANGE);
+		return ISC_R_RANGE;
 	}
 #else
 	if (t->seconds < i->seconds) {
-		return (ISC_R_RANGE);
+		return ISC_R_RANGE;
 	}
 	result->seconds = t->seconds - i->seconds;
 #endif
@@ -279,14 +274,14 @@ isc_time_subtract(const isc_time_t *t, const isc_interval_t *i,
 		result->nanoseconds = t->nanoseconds - i->nanoseconds;
 	} else {
 		if (result->seconds == 0) {
-			return (ISC_R_RANGE);
+			return ISC_R_RANGE;
 		}
 		result->seconds--;
-		result->nanoseconds = NS_PER_S + t->nanoseconds -
+		result->nanoseconds = NS_PER_SEC + t->nanoseconds -
 				      i->nanoseconds;
 	}
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 uint64_t
@@ -294,13 +289,13 @@ isc_time_microdiff(const isc_time_t *t1, const isc_time_t *t2) {
 	uint64_t i1, i2, i3;
 
 	REQUIRE(t1 != NULL && t2 != NULL);
-	INSIST(t1->nanoseconds < NS_PER_S && t2->nanoseconds < NS_PER_S);
+	INSIST(t1->nanoseconds < NS_PER_SEC && t2->nanoseconds < NS_PER_SEC);
 
-	i1 = (uint64_t)t1->seconds * NS_PER_S + t1->nanoseconds;
-	i2 = (uint64_t)t2->seconds * NS_PER_S + t2->nanoseconds;
+	i1 = (uint64_t)t1->seconds * NS_PER_SEC + t1->nanoseconds;
+	i2 = (uint64_t)t2->seconds * NS_PER_SEC + t2->nanoseconds;
 
 	if (i1 <= i2) {
-		return (0);
+		return 0;
 	}
 
 	i3 = i1 - i2;
@@ -310,15 +305,15 @@ isc_time_microdiff(const isc_time_t *t1, const isc_time_t *t2) {
 	 */
 	i3 /= NS_PER_US;
 
-	return (i3);
+	return i3;
 }
 
 uint32_t
 isc_time_seconds(const isc_time_t *t) {
 	REQUIRE(t != NULL);
-	INSIST(t->nanoseconds < NS_PER_S);
+	INSIST(t->nanoseconds < NS_PER_SEC);
 
-	return ((uint32_t)t->seconds);
+	return (uint32_t)t->seconds;
 }
 
 isc_result_t
@@ -326,7 +321,7 @@ isc_time_secondsastimet(const isc_time_t *t, time_t *secondsp) {
 	time_t seconds;
 
 	REQUIRE(t != NULL);
-	INSIST(t->nanoseconds < NS_PER_S);
+	INSIST(t->nanoseconds < NS_PER_SEC);
 
 	/*
 	 * Ensure that the number of seconds represented by t->seconds
@@ -351,21 +346,21 @@ isc_time_secondsastimet(const isc_time_t *t, time_t *secondsp) {
 	INSIST(sizeof(time_t) >= sizeof(uint32_t));
 
 	if (t->seconds > (~0U >> 1) && seconds <= (time_t)(~0U >> 1)) {
-		return (ISC_R_RANGE);
+		return ISC_R_RANGE;
 	}
 
 	*secondsp = seconds;
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 uint32_t
 isc_time_nanoseconds(const isc_time_t *t) {
 	REQUIRE(t != NULL);
 
-	ENSURE(t->nanoseconds < NS_PER_S);
+	ENSURE(t->nanoseconds < NS_PER_SEC);
 
-	return ((uint32_t)t->nanoseconds);
+	return (uint32_t)t->nanoseconds;
 }
 
 void
@@ -375,7 +370,7 @@ isc_time_formattimestamp(const isc_time_t *t, char *buf, unsigned int len) {
 	struct tm tm;
 
 	REQUIRE(t != NULL);
-	INSIST(t->nanoseconds < NS_PER_S);
+	INSIST(t->nanoseconds < NS_PER_SEC);
 	REQUIRE(buf != NULL);
 	REQUIRE(len > 0);
 
@@ -397,7 +392,7 @@ isc_time_formathttptimestamp(const isc_time_t *t, char *buf, unsigned int len) {
 	struct tm tm;
 
 	REQUIRE(t != NULL);
-	INSIST(t->nanoseconds < NS_PER_S);
+	INSIST(t->nanoseconds < NS_PER_SEC);
 	REQUIRE(buf != NULL);
 	REQUIRE(len > 0);
 
@@ -422,14 +417,14 @@ isc_time_parsehttptimestamp(char *buf, isc_time_t *t) {
 
 	p = isc_tm_strptime(buf, "%a, %d %b %Y %H:%M:%S", &t_tm);
 	if (p == NULL) {
-		return (ISC_R_UNEXPECTED);
+		return ISC_R_UNEXPECTED;
 	}
 	when = isc_tm_timegm(&t_tm);
 	if (when == -1) {
-		return (ISC_R_UNEXPECTED);
+		return ISC_R_UNEXPECTED;
 	}
 	isc_time_set(t, when, 0);
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 void
@@ -439,7 +434,7 @@ isc_time_formatISO8601L(const isc_time_t *t, char *buf, unsigned int len) {
 	struct tm tm;
 
 	REQUIRE(t != NULL);
-	INSIST(t->nanoseconds < NS_PER_S);
+	INSIST(t->nanoseconds < NS_PER_SEC);
 	REQUIRE(buf != NULL);
 	REQUIRE(len > 0);
 
@@ -455,7 +450,7 @@ isc_time_formatISO8601Lms(const isc_time_t *t, char *buf, unsigned int len) {
 	struct tm tm;
 
 	REQUIRE(t != NULL);
-	INSIST(t->nanoseconds < NS_PER_S);
+	INSIST(t->nanoseconds < NS_PER_SEC);
 	REQUIRE(buf != NULL);
 	REQUIRE(len > 0);
 
@@ -475,7 +470,7 @@ isc_time_formatISO8601Lus(const isc_time_t *t, char *buf, unsigned int len) {
 	struct tm tm;
 
 	REQUIRE(t != NULL);
-	INSIST(t->nanoseconds < NS_PER_S);
+	INSIST(t->nanoseconds < NS_PER_SEC);
 	REQUIRE(buf != NULL);
 	REQUIRE(len > 0);
 
@@ -495,7 +490,7 @@ isc_time_formatISO8601(const isc_time_t *t, char *buf, unsigned int len) {
 	struct tm tm;
 
 	REQUIRE(t != NULL);
-	INSIST(t->nanoseconds < NS_PER_S);
+	INSIST(t->nanoseconds < NS_PER_SEC);
 	REQUIRE(buf != NULL);
 	REQUIRE(len > 0);
 
@@ -511,7 +506,7 @@ isc_time_formatISO8601ms(const isc_time_t *t, char *buf, unsigned int len) {
 	struct tm tm;
 
 	REQUIRE(t != NULL);
-	INSIST(t->nanoseconds < NS_PER_S);
+	INSIST(t->nanoseconds < NS_PER_SEC);
 	REQUIRE(buf != NULL);
 	REQUIRE(len > 0);
 
@@ -532,7 +527,7 @@ isc_time_formatISO8601us(const isc_time_t *t, char *buf, unsigned int len) {
 	struct tm tm;
 
 	REQUIRE(t != NULL);
-	INSIST(t->nanoseconds < NS_PER_S);
+	INSIST(t->nanoseconds < NS_PER_SEC);
 	REQUIRE(buf != NULL);
 	REQUIRE(len > 0);
 
@@ -554,7 +549,7 @@ isc_time_formatshorttimestamp(const isc_time_t *t, char *buf,
 	struct tm tm;
 
 	REQUIRE(t != NULL);
-	INSIST(t->nanoseconds < NS_PER_S);
+	INSIST(t->nanoseconds < NS_PER_SEC);
 	REQUIRE(buf != NULL);
 	REQUIRE(len > 0);
 
