@@ -40,7 +40,7 @@ make_name(const char *src, dns_name_t *name) {
 	isc_buffer_t b;
 	isc_buffer_constinit(&b, src, strlen(src));
 	isc_buffer_add(&b, strlen(src));
-	return (dns_name_fromtext(name, &b, dns_rootname, 0, NULL));
+	return dns_name_fromtext(name, &b, dns_rootname, 0, NULL);
 }
 
 /* create: make sure we can create a dbiterator */
