@@ -49,7 +49,7 @@ cleanup(void **state __attribute__((__unused__))) {
 	(void)isc_file_remove(TAPFILE);
 	(void)isc_file_remove(TAPSOCK);
 
-	return (0);
+	return 0;
 }
 
 static int
@@ -64,7 +64,7 @@ setup(void **state) {
 	 * the testdata was originally generated.
 	 */
 	setenv("TZ", "PDT8", 1);
-	return (0);
+	return 0;
 }
 
 /* set up dnstap environment */
