@@ -24,6 +24,7 @@
 #define UNIT_TESTING
 #include <cmocka.h>
 
+#include <isc/print.h>
 #include <isc/util.h>
 
 #include <dns/stats.h>
@@ -111,7 +112,7 @@ verify_active_counters(dns_rdatastatstype_t which, uint64_t value, void *arg) {
 		ATTRIBUTE_SET(DNS_RDATASTATSTYPE_ATTR_ANCIENT) ? "~" : " ",
 		ATTRIBUTE_SET(DNS_RDATASTATSTYPE_ATTR_STALE) ? "#" : " ",
 		ATTRIBUTE_SET(DNS_RDATASTATSTYPE_ATTR_NXDOMAIN) ? "X" : " ",
-		type, (unsigned int)value);
+		type, (unsigned)value);
 #endif /* if debug */
 	if ((attributes & DNS_RDATASTATSTYPE_ATTR_ANCIENT) == 0 &&
 	    (attributes & DNS_RDATASTATSTYPE_ATTR_STALE) == 0)
@@ -142,7 +143,7 @@ verify_stale_counters(dns_rdatastatstype_t which, uint64_t value, void *arg) {
 		ATTRIBUTE_SET(DNS_RDATASTATSTYPE_ATTR_ANCIENT) ? "~" : " ",
 		ATTRIBUTE_SET(DNS_RDATASTATSTYPE_ATTR_STALE) ? "#" : " ",
 		ATTRIBUTE_SET(DNS_RDATASTATSTYPE_ATTR_NXDOMAIN) ? "X" : " ",
-		type, (unsigned int)value);
+		type, (unsigned)value);
 #endif /* if debug */
 	if ((attributes & DNS_RDATASTATSTYPE_ATTR_STALE) != 0) {
 		assert_int_equal(value, 1);
@@ -171,7 +172,7 @@ verify_ancient_counters(dns_rdatastatstype_t which, uint64_t value, void *arg) {
 		ATTRIBUTE_SET(DNS_RDATASTATSTYPE_ATTR_ANCIENT) ? "~" : " ",
 		ATTRIBUTE_SET(DNS_RDATASTATSTYPE_ATTR_STALE) ? "#" : " ",
 		ATTRIBUTE_SET(DNS_RDATASTATSTYPE_ATTR_NXDOMAIN) ? "X" : " ",
-		type, (unsigned int)value);
+		type, (unsigned)value);
 #endif /* if debug */
 	if ((attributes & DNS_RDATASTATSTYPE_ATTR_ANCIENT) != 0) {
 		assert_int_equal(value, 1);
@@ -188,12 +189,16 @@ verify_ancient_counters(dns_rdatastatstype_t which, uint64_t value, void *arg) {
  * active -> stale -> ancient.
  */
 static void
-rdatasetstats(void **state ISC_ATTR_UNUSED, bool servestale) {
+rdatasetstats(void **state, bool servestale) {
 	unsigned int i;
 	unsigned int from = 0;
 	dns_stats_t *stats = NULL;
+	isc_result_t result;
 
-	dns_rdatasetstats_create(mctx, &stats);
+	UNUSED(state);
+
+	result = dns_rdatasetstats_create(mctx, &stats);
+	assert_int_equal(result, ISC_R_SUCCESS);
 
 	/* First 255 types. */
 	for (i = 1; i <= 255; i++) {
