@@ -214,7 +214,7 @@ setup_ephemeral_port(isc_sockaddr_t *addr, sa_family_t family) {
 	fd = socket(AF_INET6, family, 0);
 	if (fd < 0) {
 		perror("setup_ephemeral_port: socket()");
-		return (-1);
+		return -1;
 	}
 
 	r = bind(fd, (const struct sockaddr *)&addr->type.sa,
@@ -222,14 +222,14 @@ setup_ephemeral_port(isc_sockaddr_t *addr, sa_family_t family) {
 	if (r != 0) {
 		perror("setup_ephemeral_port: bind()");
 		isc__nm_closesocket(fd);
-		return (r);
+		return r;
 	}
 
 	r = getsockname(fd, (struct sockaddr *)&addr->type.sa, &addrlen);
 	if (r != 0) {
 		perror("setup_ephemeral_port: getsockname()");
 		isc__nm_closesocket(fd);
-		return (r);
+		return r;
 	}
 
 #if IPV6_RECVERR
@@ -240,11 +240,11 @@ setup_ephemeral_port(isc_sockaddr_t *addr, sa_family_t family) {
 	if (r != 0) {
 		perror("setup_ephemeral_port");
 		isc__nm_closesocket(fd);
-		return (r);
+		return r;
 	}
 #endif
 
-	return (fd);
+	return fd;
 }
 
 static int
@@ -275,7 +275,7 @@ setup_test(void **state __attribute__((unused))) {
 	udp_listen_addr = (isc_sockaddr_t){ .length = 0 };
 	udp_listen_sock = setup_ephemeral_port(&udp_listen_addr, SOCK_DGRAM);
 	if (udp_listen_sock < 0) {
-		return (-1);
+		return -1;
 	}
 	isc__nm_closesocket(udp_listen_sock);
 	udp_listen_sock = -1;
@@ -286,7 +286,7 @@ setup_test(void **state __attribute__((unused))) {
 	tcp_listen_addr = (isc_sockaddr_t){ .length = 0 };
 	tcp_listen_sock = setup_ephemeral_port(&tcp_listen_addr, SOCK_STREAM);
 	if (tcp_listen_sock < 0) {
-		return (-1);
+		return -1;
 	}
 	isc__nm_closesocket(tcp_listen_sock);
 	tcp_listen_sock = -1;
@@ -314,7 +314,7 @@ setup_test(void **state __attribute__((unused))) {
 	isc_nonce_buf(&send_magic, sizeof(send_magic));
 	isc_nonce_buf(&stop_magic, sizeof(stop_magic));
 	if (send_magic == stop_magic) {
-		return (-1);
+		return -1;
 	}
 
 	isc__netmgr_create(mctx, nworkers, &listen_nm);
@@ -336,10 +336,10 @@ setup_test(void **state __attribute__((unused))) {
 	if (isc_tlsctx_createserver(NULL, NULL, &tcp_listen_tlsctx) !=
 	    ISC_R_SUCCESS)
 	{
-		return (-1);
+		return -1;
 	}
 	if (isc_tlsctx_createclient(&tcp_connect_tlsctx) != ISC_R_SUCCESS) {
-		return (-1);
+		return -1;
 	}
 
 	isc_tlsctx_enable_dot_client_alpn(tcp_connect_tlsctx);
@@ -349,7 +349,7 @@ setup_test(void **state __attribute__((unused))) {
 		ISC_TLSCTX_CLIENT_SESSION_CACHE_DEFAULT_SIZE,
 		&tcp_tlsctx_client_sess_cache);
 
-	return (0);
+	return 0;
 }
 
 static int
@@ -379,7 +379,7 @@ teardown_test(void **state __attribute__((unused))) {
 
 	isc_tlsctx_client_session_cache_detach(&tcp_tlsctx_client_sess_cache);
 
-	return (0);
+	return 0;
 }
 
 /* Callbacks */
@@ -402,7 +402,7 @@ noop_accept_cb(isc_nmhandle_t *handle, isc_result_t result, void *cbarg) {
 		(void)atomic_fetch_add(&saccepts, 1);
 	}
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static void
@@ -569,7 +569,7 @@ listen_accept_cb(isc_nmhandle_t *handle, isc_result_t eresult, void *cbarg) {
 
 	F();
 
-	return (eresult);
+	return eresult;
 }
 
 static isc_result_t
@@ -581,7 +581,7 @@ stream_accept_cb(isc_nmhandle_t *handle, isc_result_t eresult, void *cbarg) {
 	F();
 
 	if (eresult != ISC_R_SUCCESS) {
-		return (eresult);
+		return eresult;
 	}
 
 	atomic_fetch_add(&saccepts, 1);
@@ -590,7 +590,7 @@ stream_accept_cb(isc_nmhandle_t *handle, isc_result_t eresult, void *cbarg) {
 	isc_nmhandle_attach(handle, &readhandle);
 	isc_nm_read(handle, listen_read_cb, readhandle);
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 typedef void (*connect_func)(isc_nm_t *);
@@ -617,7 +617,7 @@ connect_thread(isc_threadarg_t arg) {
 		connect(connect_nm);
 	}
 
-	return ((isc_threadresult_t)0);
+	return (isc_threadresult_t)0;
 }
 
 /* UDP */
@@ -1124,7 +1124,7 @@ tcp_listener_init_quota(size_t nthreads) {
 		isc_quota_max(&listener_quota, max_quota);
 		quotap = &listener_quota;
 	}
-	return (quotap);
+	return quotap;
 }
 
 static void
@@ -1142,10 +1142,10 @@ static stream_connect_function
 get_stream_connect_function(void) {
 #if HAVE_LIBNGHTTP2
 	if (stream_use_TLS) {
-		return (tls_connect);
+		return tls_connect;
 	}
 #endif
-	return (tcp_connect);
+	return tcp_connect;
 }
 
 static isc_result_t
@@ -1160,14 +1160,14 @@ stream_listen(isc_nm_accept_cb_t accept_cb, void *accept_cbarg,
 					  accept_cb, accept_cbarg,
 					  extrahandlesize, backlog, quota,
 					  tcp_listen_tlsctx, sockp);
-		return (result);
+		return result;
 	}
 #endif
 	result = isc_nm_listentcp(listen_nm, &tcp_listen_addr, accept_cb,
 				  accept_cbarg, extrahandlesize, backlog, quota,
 				  sockp);
 
-	return (result);
+	return result;
 }
 
 static void
@@ -2401,6 +2401,178 @@ ISC_RUN_TEST_IMPL(tlsdns_recv_one) {
 	atomic_assert_int_eq(ssends, 0);
 }
 
+#ifdef HAVE_LIBNGHTTP2
+static void
+tlsdns_many_listen_read_cb(isc_nmhandle_t *handle, isc_result_t eresult,
+			   isc_region_t *region, void *cbarg) {
+	uint64_t magic = 0;
+	isc_nmhandle_t *sendhandle = NULL;
+	isc_buffer_t *send_data = (isc_buffer_t *)cbarg;
+	isc_region_t send_messages = { 0 };
+
+	assert_non_null(handle);
+	assert_non_null(send_data);
+
+	F();
+
+	if (eresult != ISC_R_SUCCESS) {
+		goto unref;
+	}
+
+	atomic_fetch_add(&sreads, 1);
+
+	assert_true(region->length >= sizeof(magic));
+
+	memmove(&magic, region->base + sizeof(uint16_t), sizeof(magic));
+	assert_true(magic == stop_magic || magic == send_magic);
+
+	isc_nmhandle_attach(handle, &sendhandle);
+	isc_refcount_increment0(&active_ssends);
+	isc_nmhandle_setwritetimeout(sendhandle, T_IDLE);
+	/* send multiple DNS messages at once */
+	isc_buffer_usedregion(send_data, &send_messages);
+	isc_nm_send(sendhandle, &send_messages, listen_send_cb, cbarg);
+unref:
+	isc_refcount_decrement(&active_sreads);
+	isc_nmhandle_detach(&handle);
+}
+
+static isc_result_t
+tlsdns_many_listen_accept_cb(isc_nmhandle_t *handle, isc_result_t eresult,
+			     void *cbarg) {
+	isc_nmhandle_t *readhandle = NULL;
+
+	UNUSED(cbarg);
+
+	F();
+
+	if (eresult != ISC_R_SUCCESS) {
+		return eresult;
+	}
+
+	atomic_fetch_add(&saccepts, 1);
+
+	isc_refcount_increment0(&active_sreads);
+	isc_nmhandle_attach(handle, &readhandle);
+	isc_nm_read(handle, tlsdns_many_listen_read_cb, cbarg);
+
+	return ISC_R_SUCCESS;
+}
+
+static void
+tlsdns_many_connect_read_cb(isc_nmhandle_t *handle, isc_result_t eresult,
+			    isc_region_t *region, void *cbarg) {
+	isc_nmhandle_t *sendhandle = NULL;
+	uint64_t magic = 0;
+
+	UNUSED(cbarg);
+
+	assert_non_null(handle);
+
+	F();
+
+	if (eresult != ISC_R_SUCCESS) {
+		goto unref;
+	}
+
+	assert_true(region->length >= sizeof(magic));
+
+	atomic_fetch_add(&creads, 1);
+
+	memmove(&magic, region->base, sizeof(magic));
+
+	assert_true(magic == stop_magic || magic == send_magic);
+
+	isc_refcount_increment0(&active_csends);
+	isc_nmhandle_attach(handle, &sendhandle);
+	isc_nmhandle_setwritetimeout(handle, T_IDLE);
+	/*
+	 * At this point the read is completed, so we should stop that -
+	 * but the sending code will make a cycling through input
+	 * attempt. When not properly handled, this situation will cause
+	 * excessive reads.
+	 */
+	isc_nm_send(sendhandle, &send_msg, connect_send_cb, NULL);
+
+unref:
+	isc_refcount_decrement(&active_creads);
+	isc_nmhandle_detach(&handle);
+}
+
+/*
+ * A unit test *VERY* specific to #4487 - it would crash the unit test
+ * suite without the related fix due to excessive/unexpected reads.
+ *
+ * The intention behind the test is to (needlessly ;-)) prove that the
+ * author of the fix is not fantasising and excessive reads are
+ * possible in principle. Also, it proves that there is more than one
+ * way to do that.
+ *
+ * It is *not* reproducing the situation from the bug report 1:1, as
+ * it is impossible to understand what exactly was going on with this
+ * custom/proprietary server without having access to it (and even in
+ * that case the bug was hard to reproduce to the point, where the
+ * reporters considered it to be fixed for a while). There are far too
+ * many things a play.
+ */
+ISC_RUN_TEST_IMPL(tlsdns_server_send_many_recv_one) {
+	isc_result_t result = ISC_R_SUCCESS;
+	isc_nmsocket_t *listen_sock = NULL;
+	uint8_t buf[512];
+	isc_buffer_t server_send_buf = { 0 };
+
+	isc_buffer_init(&server_send_buf, buf, sizeof(buf));
+
+	/*
+	 * Prepare a buffer with three "DNS" messages which we will send
+	 * at once (our code does not normally do that do that).
+	 */
+	isc_buffer_putuint16(&server_send_buf, (uint16_t)send_msg.length);
+	isc_buffer_putmem(&server_send_buf, send_msg.base, send_msg.length);
+	isc_buffer_putuint16(&server_send_buf, (uint16_t)send_msg.length);
+	isc_buffer_putmem(&server_send_buf, send_msg.base, send_msg.length);
+	isc_buffer_putuint16(&server_send_buf, (uint16_t)send_msg.length);
+	isc_buffer_putmem(&server_send_buf, send_msg.base, send_msg.length);
+
+	atomic_store(&nsends, 1);
+
+	result = isc_nm_listentls(
+		listen_nm, &tcp_listen_addr, tlsdns_many_listen_accept_cb,
+		&server_send_buf, 0, 0, NULL, tcp_listen_tlsctx, &listen_sock);
+	assert_int_equal(result, ISC_R_SUCCESS);
+
+	connect_readcb = tlsdns_many_connect_read_cb;
+	isc_refcount_increment0(&active_cconnects);
+	isc_nm_tlsdnsconnect(connect_nm, &tcp_connect_addr, &tcp_listen_addr,
+			     connect_connect_cb, NULL, T_CONNECT, 0,
+			     tcp_connect_tlsctx, tcp_tlsctx_client_sess_cache);
+
+	WAIT_FOR_EQ(cconnects, 1);
+	WAIT_FOR_LE(nsends, 0);
+	WAIT_FOR_EQ(csends, 2);
+	WAIT_FOR_EQ(sreads, 1);
+	WAIT_FOR_EQ(ssends, 1);
+	WAIT_FOR_EQ(creads, 1);
+
+	isc_nm_stoplistening(listen_sock);
+	isc_nmsocket_close(&listen_sock);
+	assert_null(listen_sock);
+	isc__netmgr_shutdown(connect_nm);
+
+	X(cconnects);
+	X(csends);
+	X(creads);
+	X(sreads);
+	X(ssends);
+
+	atomic_assert_int_eq(cconnects, 1);
+	atomic_assert_int_eq(csends, 2);
+	atomic_assert_int_eq(creads, 1);
+	atomic_assert_int_eq(sreads, 1);
+	atomic_assert_int_eq(ssends, 1);
+}
+#endif /* HAVE_LIBNGHTTP2 */
+
 ISC_RUN_TEST_IMPL(tlsdns_recv_two) {
 	isc_result_t result = ISC_R_SUCCESS;
 	isc_nmsocket_t *listen_sock = NULL;
@@ -2718,16 +2890,16 @@ tls_accept_cb_noalpn(isc_nmhandle_t *handle, isc_result_t eresult,
 	F();
 
 	if (eresult != ISC_R_SUCCESS) {
-		return (eresult);
+		return eresult;
 	}
 
 	atomic_fetch_add(&saccepts, 1);
 
 	if (isc_nm_xfr_checkperm(handle) != ISC_R_SUCCESS) {
-		return (ISC_R_FAILURE);
+		return ISC_R_FAILURE;
 	}
 
-	return (stream_accept_cb(handle, eresult, cbarg));
+	return stream_accept_cb(handle, eresult, cbarg);
 }
 
 ISC_RUN_TEST_IMPL(tlsdns_listen_noalpn) {
@@ -2890,6 +3062,8 @@ ISC_TEST_ENTRY_CUSTOM(tlsdns_half_recv_half_send, setup_test, teardown_test)
 ISC_TEST_ENTRY_CUSTOM(tlsdns_connect_noalpn, setup_test, teardown_test)
 #ifdef HAVE_LIBNGHTTP2
 ISC_TEST_ENTRY_CUSTOM(tlsdns_listen_noalpn, setup_test, teardown_test)
+ISC_TEST_ENTRY_CUSTOM(tlsdns_server_send_many_recv_one, setup_test,
+		      teardown_test)
 #endif
 
 ISC_TEST_LIST_END
